@@ -26,7 +26,7 @@
 
 #include "../../cem/cem.h"
 #include "chum.h"
-#include "file_helper.h"
+#include "../file_helper.h"
 #include "song.h"
 static JammoSequencer* singinggame_sequencer = NULL; //used for stopping
 
@@ -134,12 +134,9 @@ static void on_sequencer_stopped_playback(JammoSequencer* sequencer_old, gpointe
 	char timestamp_now [80];
 	cem_get_time(timestamp_now);
 
-	gchar* singings_directory = configure_get_singings_directory();
-	char* filename= g_strdup_printf("%s/wavs/%s_%s.wav",singings_directory,(chum_get_current_song())->name_with_pack,timestamp_now);
+	char* filename= g_strdup_printf("%s/wavs/%s_%s.wav",configure_get_singings_directory(),(chum_get_current_song())->name_with_pack,timestamp_now);
 
-	gchar* jammo_directory=configure_get_jammo_directory();
-	cmd = g_strdup_printf("mv \"%s/last_recorded.wav\" \"%s\"", jammo_directory, filename);
-	g_free(jammo_directory);
+	cmd = g_strdup_printf("mv \"%s/last_recorded.wav\" \"%s\"", configure_get_jammo_directory(), filename);
 
 	//printf("Executing: '%s'\n",cmd);
 	if (system(cmd)) {
@@ -151,8 +148,7 @@ static void on_sequencer_stopped_playback(JammoSequencer* sequencer_old, gpointe
 
 	FILE *ofp;
 	gchar *outputFilename;
-	outputFilename = g_strdup_printf("%s/%s.json", singings_directory,(chum_get_current_song())->name_with_pack);
-	g_free(singings_directory);
+	outputFilename = g_strdup_printf("%s/%s.json", configure_get_singings_directory(),(chum_get_current_song())->name_with_pack);
 
 	//printf("outputFilename='%s'\n",outputFilename);
 	ofp = fopen(outputFilename, "w");
@@ -209,9 +205,7 @@ void on_sequencer_stopped_recording(JammoSequencer* sequencer_old, gpointer user
 
 
 	gchar *loaded_filename;
-	gchar* jammo_directory=configure_get_jammo_directory();
-	loaded_filename =  g_strdup_printf("%s/last_recorded.wav",jammo_directory);
-	g_free(jammo_directory);
+	loaded_filename =  g_strdup_printf("%s/last_recorded.wav",configure_get_jammo_directory());
 	//printf("looking for file '%s' for loaded_track\n",loaded_filename);
 
 
