@@ -27,13 +27,13 @@ static void finalize_welcome(void) {
 	}
 
 	//Do not go to main-menu, but login_screen
-	//login_screen();
-	
+	login_screen();
+	/*
 	if ((actor = jammo_get_actor_by_id("main-menu-view"))) {
 		clutter_actor_show(actor);
 		clutter_actor_queue_relayout(clutter_actor_get_parent(actor));
 	}
-	
+	*/
 
 	//Set default language for singing game
 	// It also affects first flag showed
