@@ -30,7 +30,7 @@ void start_avatar_editor(){
 
 	//Creating default user to test avatar saving!
 
-	static int start = 0; // For testing only!!!
+	static int start = 1; // For testing only!!!
 	
 	if(start){// For testing only!!!
 		gems_profile_manager_create_default_user_profile("sala", 23);// For testing only!!!
@@ -94,7 +94,7 @@ void start_avatar_editor(){
 			}
 		}
 	
-		set_avatar();
+		set_avatar(&avatar, CLUTTER_ACTOR(avatarImage), CLUTTER_ACTOR(instrumentBackground), "avatar-widgets");
 	
 	}
 
@@ -102,89 +102,98 @@ void start_avatar_editor(){
 }
 
 
-void set_avatar(){
+void set_avatar(Avatar *avatar, ClutterActor *avatarImage, ClutterActor *instrumentBackground, char *widget){
+
+
 
 	if(instrumentBackground == 0){
 
 	}
 
-	if(avatar.body == 0){
-		avatar.body = clutter_texture_new_from_file("/opt/jammo/communitymenu/AVATAR_PARTS/bodys/body_blue.png", NULL);
-		clutter_actor_set_name(avatar.body, "body_blue.png");
+	if(avatar->body == 0){
+		avatar->body = clutter_texture_new_from_file("/opt/jammo/communitymenu/AVATAR_PARTS/bodys/body_blue.png", NULL);
+		clutter_actor_set_name(avatar->body, "body_blue.png");
 	}
-	if(avatar.head == 0){
-		avatar.head = clutter_texture_new_from_file("/opt/jammo/communitymenu/AVATAR_PARTS/heads/head_yellow.png", NULL);
-	clutter_actor_set_name(avatar.head, "head_yellow.png");
+	if(avatar->head == 0){
+		avatar->head = clutter_texture_new_from_file("/opt/jammo/communitymenu/AVATAR_PARTS/heads/head_yellow.png", NULL);
+	clutter_actor_set_name(avatar->head, "head_yellow.png");
 	}
 
 	if(avatarImage == 0){
-		avatarImage = CLUTTER_CONTAINER(jammo_get_actor_by_id("avatar-widgets")); 
+		avatarImage = (jammo_get_actor_by_id(widget)); 
 
 	}
 	
 	
-	clutter_container_add_actor(avatarImage, avatar.head);
-	clutter_actor_set_position(avatar.head, 92, 85);
+	clutter_container_add_actor(CLUTTER_CONTAINER(avatarImage), avatar->head);
+	clutter_actor_set_position(avatar->head, 92, 85);
 	
-	clutter_container_add_actor(avatarImage, avatar.body);
-	clutter_actor_set_position(avatar.body, 65, 170);
+	clutter_container_add_actor(CLUTTER_CONTAINER(avatarImage), avatar->body);
+	clutter_actor_set_position(avatar->body, 65, 170);
 	
-	if(avatar.instrument != 0){
+	if(avatar->instrument != 0){
 
 		if(instrumentBackground == 0){
 			instrumentBackground = clutter_texture_new_from_file("/opt/jammo/communitymenu/community_avatar_avatarbackground.png", NULL);
 			clutter_actor_set_size(instrumentBackground, 110, 110);
-			clutter_actor_set_position(instrumentBackground, 503, 238);
-			clutter_container_add_actor(avatarImage, instrumentBackground);
+			clutter_container_add_actor(CLUTTER_CONTAINER(avatarImage), instrumentBackground);
 		}		
 		
-		clutter_actor_set_position(avatar.instrument, 510, 245);
-		clutter_container_add_actor(avatarImage, avatar.instrument);
+		if(strcmp(widget, "user-profile-widgets") == 0){
+			clutter_actor_set_position(instrumentBackground, 503, 260);
+			clutter_actor_set_position(avatar->instrument, 510, 267);
+		}else{
+			clutter_actor_set_position(instrumentBackground, 503, 238);
+			clutter_actor_set_position(avatar->instrument, 510, 245);
+		}
+		
+		clutter_container_add_actor(CLUTTER_CONTAINER(avatarImage), avatar->instrument);
+		clutter_actor_raise(avatar->instrument, instrumentBackground);
 	}
 	
 	
-	if(avatar.hair != 0){
+	if(avatar->hair != 0){
 	
-		clutter_container_add_actor(avatarImage, avatar.hair);
+		clutter_container_add_actor(CLUTTER_CONTAINER(avatarImage), avatar->hair);
 
 		//this must be done since each hair image requires own coordinates
 		
-		if(strstr(clutter_actor_get_name(avatar.hair), "hair_bush.png"))
-			clutter_actor_set_position(avatar.hair, 85, 70);
-		if(strstr(clutter_actor_get_name(avatar.hair), "hair_centerspread.png"))
-			clutter_actor_set_position(avatar.hair, 70, 80);		
-		if(strstr(clutter_actor_get_name(avatar.hair), "hair_centerspread2.png"))
-			clutter_actor_set_position(avatar.hair, 80, 70);
-		if(strstr(clutter_actor_get_name(avatar.hair), "hair_centerspread3.png"))
-			clutter_actor_set_position(avatar.hair, 83, 72);
-		if(strstr(clutter_actor_get_name(avatar.hair), "hair_centerspread4.png"))
-			clutter_actor_set_position(avatar.hair, 90, 79);
-		if(strstr(clutter_actor_get_name(avatar.hair), "hair_centerspread5.png"))
-			clutter_actor_set_position(avatar.hair, 92, 81);
-		if(strstr(clutter_actor_get_name(avatar.hair), "hair_emo.png"))
-			clutter_actor_set_position(avatar.hair, 89, 78);
-		if(strstr(clutter_actor_get_name(avatar.hair), "hair_long.png"))
-			clutter_actor_set_position(avatar.hair, 80, 69);
-		if(strstr(clutter_actor_get_name(avatar.hair), "hair_longcurly.png"))
-			clutter_actor_set_position(avatar.hair, 78, 73);
-		if(strstr(clutter_actor_get_name(avatar.hair), "hair_longcurly2.png"))
-			clutter_actor_set_position(avatar.hair, 80, 72);
-		if(strstr(clutter_actor_get_name(avatar.hair), "hair_mohawk.png"))
-			clutter_actor_set_position(avatar.hair, 106, 60);
-		if(strstr(clutter_actor_get_name(avatar.hair), "hair_ponytails.png"))
-			clutter_actor_set_position(avatar.hair, 75, 75);
-		if(strstr(clutter_actor_get_name(avatar.hair), "hair_punk.png"))
-			clutter_actor_set_position(avatar.hair, 80, 64);
-		if(strstr(clutter_actor_get_name(avatar.hair), "hair_punk2.png"))	
-			clutter_actor_set_position(avatar.hair, 50, 35);
-		if(strstr(clutter_actor_get_name(avatar.hair), "hair_top.png"))	
-			clutter_actor_set_position(avatar.hair, 100, 80);
+		if(strstr(clutter_actor_get_name(avatar->hair), "hair_bush.png"))
+			clutter_actor_set_position(avatar->hair, 85, 70);
+		if(strstr(clutter_actor_get_name(avatar->hair), "hair_centerspread.png"))
+			clutter_actor_set_position(avatar->hair, 70, 80);		
+		if(strstr(clutter_actor_get_name(avatar->hair), "hair_centerspread2.png"))
+			clutter_actor_set_position(avatar->hair, 80, 70);
+		if(strstr(clutter_actor_get_name(avatar->hair), "hair_centerspread3.png"))
+			clutter_actor_set_position(avatar->hair, 83, 72);
+		if(strstr(clutter_actor_get_name(avatar->hair), "hair_centerspread4.png"))
+			clutter_actor_set_position(avatar->hair, 90, 79);
+		if(strstr(clutter_actor_get_name(avatar->hair), "hair_centerspread5.png"))
+			clutter_actor_set_position(avatar->hair, 92, 81);
+		if(strstr(clutter_actor_get_name(avatar->hair), "hair_emo.png"))
+			clutter_actor_set_position(avatar->hair, 89, 78);
+		if(strstr(clutter_actor_get_name(avatar->hair), "hair_long.png"))
+			clutter_actor_set_position(avatar->hair, 80, 69);
+		if(strstr(clutter_actor_get_name(avatar->hair), "hair_longcurly.png"))
+			clutter_actor_set_position(avatar->hair, 78, 73);
+		if(strstr(clutter_actor_get_name(avatar->hair), "hair_longcurly2.png"))
+			clutter_actor_set_position(avatar->hair, 80, 72);
+		if(strstr(clutter_actor_get_name(avatar->hair), "hair_mohawk.png"))
+			clutter_actor_set_position(avatar->hair, 106, 60);
+		if(strstr(clutter_actor_get_name(avatar->hair), "hair_ponytails.png"))
+			clutter_actor_set_position(avatar->hair, 75, 75);
+		if(strstr(clutter_actor_get_name(avatar->hair), "hair_punk.png"))
+			clutter_actor_set_position(avatar->hair, 80, 64);
+		if(strstr(clutter_actor_get_name(avatar->hair), "hair_punk2.png"))	
+			clutter_actor_set_position(avatar->hair, 50, 35);
+		if(strstr(clutter_actor_get_name(avatar->hair), "hair_top.png"))	
+			clutter_actor_set_position(avatar->hair, 100, 80);
 		
 	}
 	
-	clutter_actor_raise(avatar.body, avatar.head);
-	if(avatar.hair != 0)
-		clutter_actor_raise(avatar.hair, avatar.head);
+	clutter_actor_raise(avatar->body, avatar->head);
+	if(avatar->hair != 0)
+		clutter_actor_raise(avatar->hair, avatar->head);
 
 }
 
@@ -224,7 +233,7 @@ void pressed(ClutterActor *actor){
 
 		}
 
-	set_avatar();
+	set_avatar(&avatar, CLUTTER_ACTOR(avatarImage), CLUTTER_ACTOR(instrumentBackground), "avatar-widgets");
 
 }
 
@@ -271,7 +280,7 @@ void change_hair_color(){
 		DESTROY_ACTOR(avatar.hair);	
 		avatar.hair = clutter_texture_new_from_file(path, NULL);puts(path);	
 		clutter_actor_set_name(avatar.hair, path);	
-		set_avatar();
+		set_avatar(&avatar, CLUTTER_ACTOR(avatarImage), CLUTTER_ACTOR(instrumentBackground), "avatar-widgets");
 
 	}
 		
@@ -328,7 +337,7 @@ void change_head(){
 	avatar.head = clutter_texture_new_from_file(path, NULL);
 	clutter_actor_set_name(avatar.head, path);
 		     
-	set_avatar();
+	set_avatar(&avatar, CLUTTER_ACTOR(avatarImage), CLUTTER_ACTOR(instrumentBackground), "avatar-widgets");
 	
 }
 
