@@ -10,6 +10,7 @@ This file contains the functionality of help menu.
 #include "../jammo.h"
 #include "help.h"
 #include "community_utilities.h"
+#include "profile_viewer.h"
 #include "single_thread.h"
 #include "src/configure.h"
 #include <libintl.h>
@@ -19,11 +20,12 @@ static ClutterContainer *questionlist = 0;
 static gint listItemHeight = 0;
 static int selectedQuestion = 0;
 static GList *helpdesk_messages = 0;
+static GList *paramsList = 0;
 
 TextField addquestion_titleTextField;
 TextField addquestion_questionTextField;
 
-void start_helpdesk()
+void start_helpdesk(void)
 {
 	cem_add_to_log(_("Starting Helpdesk"), J_LOG_DEBUG);
 	helpdesk_messages = 0;
@@ -33,26 +35,16 @@ void start_helpdesk()
 
 void helpdesk_goto_communitymenu(TangleButton *tanglebutton, gpointer none)
 {
-	clear_container(questionlist);
-	clear_messagelist(helpdesk_messages);
-	g_list_free(helpdesk_messages);
+	end_helpdesk();
 	start_communitymenu();
 }
 
 void helpdesk_goto_startmenu(TangleButton *tanglebutton, gpointer none)
 {
-	clear_container(questionlist);
-	clear_messagelist(helpdesk_messages);
-	g_list_free(helpdesk_messages);
+	end_helpdesk();
 	startmenu_goto_startmenu(tanglebutton, none);
 }
 
-void helpdesk_return_from_threads_view(GList *messagelist)
-{
-	helpdesk_messages = messagelist;
-	helpdesk_show_helpdesk_view();
-}
-
 gboolean helpdesk_mentor_clicked (TangleButton *tanglebutton, gpointer data)   
 {
 	cem_add_to_log(_("Mentor Clicked"), J_LOG_DEBUG);
@@ -65,6 +57,18 @@ void helpdesk_get_questions(void)
 	cem_add_to_log(_("Fetching Questions From Community Server"), J_LOG_DEBUG);
 }
 
+void end_helpdesk(void)
+{
+	
+	community_clear_paramslist(paramsList);
+	
+	paramsList = 0;
+
+	clear_container(questionlist);
+	clear_messagelist(helpdesk_messages);
+	g_list_free(helpdesk_messages);
+}
+
 GList* helpdesk_get_number_of_questions(void)
 {
 	GList *temp = 0;
@@ -132,7 +136,7 @@ void helpdesk_show_helpdesk_view(void)
 
 				message *msg = questions->data;
 
-				helpdesk_add_question_to_list(msg, i);
+				helpdesk_add_question_to_list(msg, i, 0);
 				i++;
 			}while(questions->next != NULL);
 		}
@@ -220,11 +224,11 @@ void helpdesk_add_question(void)
 
 	now = get_current_time();
 
-	msg = malloc(sizeof (message));
+	msg = calloc(sizeof (message), 1);
 	msg->index = index;
 	msg->msg = malloc(strlen(clutter_text_get_text(CLUTTER_TEXT(addquestion_questionTextField.text)))+1);
 	strcpy(msg->msg, clutter_text_get_text(CLUTTER_TEXT(addquestion_questionTextField.text)));
-	strcpy(msg->avatar, "Avatar");
+	msg->user_id = 0; //TODO: this must be the user_id of the writer of the question
 	strncpy(msg->title, clutter_text_get_text(CLUTTER_TEXT(addquestion_titleTextField.text)), 100);
 	msg->title[99] = 0;
 	strncpy(msg->sender, "Sender",20);
@@ -251,37 +255,54 @@ void helpdesk_autoscroll_to_correct_pos(ClutterActor *listToScroll)
 	tangle_object_animate(G_OBJECT(action), CLUTTER_EASE_IN_OUT_QUAD, 300, "offset-y", (gfloat)(slot*listItemHeight), NULL);
 }
 
-gboolean helpdesk_add_question_to_list(gpointer data, int index)
+gboolean helpdesk_add_question_to_list(gpointer data, int index, guint user_id)
 {	
-	message *msg = data;
-	char topictitle[33];
+	ClutterContainer *listContainer = CLUTTER_CONTAINER(clutter_group_new());
+	ClutterActor *colorbar = clutter_texture_new_from_file("/opt/jammo/communitymenu/colorbar13.png",NULL);
+	ClutterActor *avatarBackground = clutter_group_new();
+	ClutterActor *composer = tangle_button_new_with_background_actor(avatarBackground);
+	ClutterActor *commentButton = tangle_button_new_with_background_actor(clutter_texture_new_from_file(
+					"communitymenu/community_comment_icon.png", NULL));
+	clutter_container_add_actor(CLUTTER_CONTAINER(avatarBackground), clutter_texture_new_from_file("/opt/jammo/communitymenu/community_avatarbackground_small.png", NULL));
 
+	message *msg = data;
+
+	char topictitle[33];
 	strncpy(topictitle, msg->title, 33);
 	topictitle[29] = topictitle[30] = topictitle[31] = '.'; 
 	topictitle[32] ='\0'; 
 
-	ClutterActor *colorbar = clutter_texture_new_from_file("/opt/jammo/communitymenu/colorbar13.png",NULL);
-	ClutterActor *avatarImage = clutter_texture_new_from_file("/opt/jammo/communitymenu/community_avatarbackground_small.png", NULL);
-
 	ClutterActor *text = clutter_text_new_with_text("Comic Sans 20", topictitle);	
 	ClutterActor *questionButton = tangle_button_new_with_background_actor(text);
 
-	ClutterActor *commentButton = tangle_button_new_with_background_actor(clutter_texture_new_from_file(
-					"communitymenu/community_comment_icon.png", NULL));
+	profile_view_params *params = malloc(sizeof(profile_view_params));
+	strcpy(params->parent_view, "helpdesk");
+	params->user_id = user_id;
 
-	ClutterContainer *listContainer = CLUTTER_CONTAINER(clutter_group_new());
+	paramsList = g_list_append(paramsList, params);
 
-	if(avatarImage == NULL || colorbar == NULL || commentButton == NULL)
+	guint32 avatar_id = gems_profile_manager_get_avatar_id(NULL);
+
+	if (avatar_id == 0)
+		avatar_id = 260; //default avatar
+
+	Avatar avatar = {0,0,0,0};
+
+	community_get_avatar(&avatar, avatar_id);
+	community_shrink_and_set_avatar(&avatar, CLUTTER_CONTAINER(avatarBackground));	
+
+	clutter_container_add_actor(listContainer, composer);
+
+	if(colorbar == NULL || commentButton == NULL)
 	{	
 		printf(_("NULL Pointer Detected!\n"));
 		return FALSE;	
 	}
 
-	if(listItemHeight == 0) listItemHeight = clutter_actor_get_height(avatarImage) + 1;
+	if(listItemHeight == 0) listItemHeight = clutter_actor_get_height(composer) + 1;
 
 	clutter_actor_set_position(colorbar, 0, listItemHeight - 1);
 	clutter_container_add_actor(listContainer, colorbar);		//Add components inside the container
-	clutter_container_add_actor(listContainer, avatarImage);
 
 	clutter_actor_set_position(questionButton, 60, 23);			
 	clutter_container_add_actor(listContainer, questionButton);
@@ -294,6 +315,7 @@ gboolean helpdesk_add_question_to_list(gpointer data, int index)
 
 	g_signal_connect_swapped(CLUTTER_ACTOR(commentButton), "clicked", G_CALLBACK(helpdesk_show_question_view), 
 						clutter_actor_get_parent(commentButton));
+	g_signal_connect_swapped(CLUTTER_ACTOR(composer), "clicked", G_CALLBACK(start_profile_view), (gpointer)params);
 
 	clutter_container_add_actor(questionlist, CLUTTER_ACTOR(listContainer));
 
