@@ -12,15 +12,16 @@ This file contains the functionality of Help menu.
 #define MAX_QUESTIONS 15
 #define MAX_COMMENTS 15
 
-void start_helpdesk();
+void start_helpdesk(void);
 void helpdesk_goto_communitymenu(TangleButton *tanglebutton, gpointer none);
 void helpdesk_goto_startmenu(TangleButton *tanglebutton, gpointer none);
+void end_helpdesk(void);
 
 void helpdesk_get_questions(void);
 GList* helpdesk_get_number_of_questions(void);
 
 //Functions for creating and moving loops
-gboolean helpdesk_add_question_to_list(gpointer data, int index);
+gboolean helpdesk_add_question_to_list(gpointer data, int index, guint user_id);
 void helpdesk_autoscroll_to_correct_pos(ClutterActor *listToScroll);
 void helpdesk_find_selected_actor(ClutterActor *actor);
 
@@ -31,5 +32,4 @@ void helpdesk_show_question_view(ClutterActor *actor);
 void helpdesk_show_helpdesk_view(void);
 void helpdesk_show_addquestion_view(void);
 
-void helpdesk_return_from_threads_view(GList *messagelist);
 #endif 
