@@ -15,6 +15,7 @@ This file contains the functionality of JamMo Songs menu.
 #include <meam/jammo-backing-track.h>
 #include "single_thread.h"
 #include "src/configure.h"
+#include "profile_viewer.h"
 
 
 static void autoscroll_to_correct_pos(ClutterActor *listToScroll);
@@ -25,6 +26,7 @@ static gboolean isrecording_voice_comment = FALSE;
 static gboolean voice_comment_ready = FALSE;
 gchar* recording_filename;
 JammoSequencer* sequencer;
+GList *paramsList = 0;
 
 void start_jammosongs(){
 
@@ -54,7 +56,7 @@ void start_jammosongs(){
 
 
 		for(int i = 0; i < numberOfSongs; i++){
-			add_song_to_list(NULL, i);	
+			add_song_to_list(NULL, i, 0);	//TODO: third parameter must be user id of the composer
 		}
 
 	ClutterAction *listAction = tangle_actor_get_action_by_type(CLUTTER_ACTOR(list), TANGLE_TYPE_SCROLL_ACTION);
@@ -88,7 +90,15 @@ static void autoscroll_to_correct_pos(ClutterActor *listToScroll){
 }
 
 
-gboolean add_song_to_list(char* loopName, int numberOfSongs){
+gboolean add_song_to_list(char* loopName, int numberOfSongs, guint32 user_id){
+
+	profile_view_params *params = malloc(sizeof(profile_view_params));
+	paramsList = g_list_append(paramsList, params);
+	strcpy(params->parent_view, "jammosongs");
+	params->user_id = user_id;
+
+	guint32 avatar_id = 0;
+	Avatar avatar = {0,0,0,0};
 
 	ClutterActor *listImage = clutter_texture_new_from_file("/opt/jammo/communitymenu/colorbar4.png", NULL); //TODO: image color depends on the song
 
@@ -96,7 +106,11 @@ gboolean add_song_to_list(char* loopName, int numberOfSongs){
 
 	ClutterActor *reviewButton = tangle_button_new_with_background_actor(clutter_texture_new_from_file(
 			"/opt/jammo/communitymenu/community_comment_icon.png", NULL));
-			
+	
+	ClutterActor *avatarBackground = clutter_group_new();	
+	clutter_container_add_actor(CLUTTER_CONTAINER(avatarBackground), clutter_texture_new_from_file("/opt/jammo/communitymenu/community_avatarbackground_small.png", NULL));
+	ClutterActor *composer = tangle_button_new_with_background_actor(avatarBackground);		
+	
 			
 	//TODO: add correct font for the text		
 
@@ -112,6 +126,17 @@ gboolean add_song_to_list(char* loopName, int numberOfSongs){
 	
 	clutter_actor_set_position(songName, 200, listItemHeight/5*2);
 	
+	clutter_actor_set_position(composer, 20, 0);
+	
+	avatar_id = gems_profile_manager_get_avatar_id(NULL);
+	if (avatar_id == 0)
+		avatar_id = 260; //default avatar
+		
+	community_get_avatar(&avatar, avatar_id);
+	community_shrink_and_set_avatar(&avatar, CLUTTER_CONTAINER(avatarBackground));	
+	
+	clutter_container_add_actor(listContainer, composer);
+	
 	clutter_container_add_actor(listContainer, songName);
 	
 	//TODO: add following images only if there is a music video or label for the song
@@ -119,15 +144,6 @@ gboolean add_song_to_list(char* loopName, int numberOfSongs){
 	ClutterActor *video = tangle_button_new_with_background_actor(clutter_texture_new_from_file("/opt/jammo/communitymenu/community_videocamera_icon_small.png", NULL));
 	clutter_actor_set_position(video, 580, listItemHeight/3);
 	clutter_container_add_actor(listContainer, video);
-	
-
-	ClutterActor *rec = tangle_button_new_with_background_actor
-		(clutter_texture_new_from_file("/opt/jammo/sequencer/label_audio.png", NULL));
-
-
-	clutter_actor_set_position(rec, 660, listItemHeight/3);
-	clutter_actor_set_size(rec, 55, 28);
-	clutter_container_add_actor(listContainer, rec);	
 
 	ClutterActor *label = tangle_button_new_with_background_actor(clutter_texture_new_from_file("/opt/jammo/communitymenu/community_cdlabel_small.png", NULL));
 
@@ -135,19 +151,19 @@ gboolean add_song_to_list(char* loopName, int numberOfSongs){
 	clutter_container_add_actor(listContainer, label);
 	
 
-	clutter_actor_set_position(CLUTTER_ACTOR(reviewButton), 740, 15);
+	clutter_actor_set_position(CLUTTER_ACTOR(reviewButton), 700, 15);
 
 	clutter_container_add_actor(listContainer, CLUTTER_ACTOR(reviewButton));
 	
 	g_signal_connect_swapped(reviewButton, "clicked", G_CALLBACK(review_selected_song), 
 				clutter_actor_get_parent(reviewButton));
-				
-	g_signal_connect_swapped(rec, "clicked", G_CALLBACK(rec_press_action), rec);
 
 	g_signal_connect_swapped(songName, "button-press-event", G_CALLBACK(song_name_press_action), songName);
-	g_signal_connect_swapped(songName, "button-release-event", G_CALLBACK(song_name_press_action), songName);			
+	g_signal_connect_swapped(songName, "button-release-event", G_CALLBACK(song_name_press_action), songName);				
 	g_signal_connect_swapped(video, "clicked", G_CALLBACK(show_music_video), songName);
 	g_signal_connect_swapped(label, "clicked", G_CALLBACK(show_song_label), songName);	
+	
+	g_signal_connect_swapped(composer, "clicked", G_CALLBACK(start_profile_view), (gpointer)params);
 
 	clutter_container_add_actor(list, CLUTTER_ACTOR(listContainer));
 	
@@ -175,23 +191,28 @@ void review_selected_song(ClutterActor *song){
 	if(isrecording_voice_comment)
 		stop_recording();
 
+//NOTE: when creting messages, message structure and variables msg and avatar inside structure
+//	must be dynamically allocated
+
+
 	for(i = 0; i < 3 /*this should be the number of messages*/; i++){
 		msg = malloc(sizeof (message));
+		
+		msg->filepath = 0;
 
 		msg->index = 0; //Index of this comment
 
 		msg->msg = malloc(strlen("Message#1")+sizeof(char));
 		sprintf(msg->msg, "Message#%d", i+1);
-		strcpy(msg->avatar, "x");
+		msg->user_id = 0; //this should be the user id of the message writer			
 		strcpy(msg->title, "");
 		strcpy(msg->sender, "Teppo");
 		strcpy(msg->time, "21.1.2011 10:09");
-		strcpy(msg->filepath, g_strdup_printf("%s/last_recorded.ogg",configure_get_jammo_directory()) );
-		msg->type = VOICE_COMMENT;
+		msg->type = TEXT_COMMENT;
 
 		messages = g_list_append(messages, (gpointer)msg);
 	}
-	
+
 	int first = 0;
 	
 	if(children != NULL){
@@ -224,6 +245,10 @@ void review_selected_song(ClutterActor *song){
 
 void end_jammosongs(TangleButton *tanglebutton, gpointer none){
 
+	community_clear_paramslist(paramsList);
+
+	paramsList = 0;
+
 	clear_container(list);
 
 	if(isrecording_voice_comment)
@@ -267,6 +292,8 @@ void record_voice_comment(){
 	isrecording_voice_comment = TRUE;
 
 	jammo_sequencer_play(JAMMO_SEQUENCER(sequencer));
+	
+	
 }
 
 
@@ -285,8 +312,49 @@ static void on_recording_stopped(JammoSequencer* sequencer, gpointer user_data)
 	isrecording_voice_comment = FALSE;
 }
 
-void rec_press_action(){
+void rec_press_action(ClutterActor *song){
 
+	
+	GList *children = clutter_container_get_children(list);
+	GList* messages = NULL;
+	//TODO: get messages to list
+	message *msg;
+	int i;
+	time_t now;
+
+
+//NOTE: when creting messages, message structure and variables msg and avatar inside structure
+//	must be dynamically allocated
+puts("1");
+	
+	
+	int first = 0;
+	
+	if(children != NULL){
+puts("2");		
+		do{
+			if(first == 0)
+				first++;
+			else	
+				children = children->next;
+				
+		
+			if(song == children->data){puts("3");
+				puts("found it");
+				clear_container(list);
+				ClutterActor* mainview = jammo_get_actor_by_id("main-views-widget");
+				clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);//TODO: get voice comments of the song
+				start_thread_view(messages, "jammosongs-voice", NULL, 0);
+				
+				break;
+				}
+		
+		}while(children->next != NULL);
+	
+	}
+	
+	g_list_free(children);
+	/*
 	static gboolean isrecording = FALSE;
 
 	if(isrecording == FALSE){
@@ -295,5 +363,5 @@ void rec_press_action(){
 	}else{
 		stop_recording();
 		isrecording = FALSE;
-	}
+	}*/
 }
