@@ -101,6 +101,7 @@ gboolean mysongs_mentor_clicked (TangleButton *tanglebutton, gpointer data)   {
 	return TRUE;
 }
 
+
 void mysongs_autoscroll_to_correct_pos(ClutterActor *listToScroll)
 {
 	gint slot;
@@ -156,7 +157,7 @@ gboolean mysongs_add_loop_to_list(char* filename, int type)
 			break;
 	}
 
-	int i, length; //29
+	int i, length, path_length=0, type_length=0;
 	int y = 0;
 	length = strlen(filename);
 
@@ -165,23 +166,18 @@ gboolean mysongs_add_loop_to_list(char* filename, int type)
 	strcpy(temp, filename);
 
 	if(type == 0){ //projects
-
-		for(i=28; i<length-5; i++){
-			filename_for_textbutton[y] = temp[i];
-			y++;
-		}
-		filename_for_textbutton[y] = '\0';
-
+		path_length = strlen(configure_get_projects_directory());
+		type_length = 5; //.json
 	}else if(type == 1){ //songs
-
-		for(i=29; i<length-4; i++){
-			filename_for_textbutton[y] = temp[i];
-			y++;
-		}
-		filename_for_textbutton[y] = '\0';
-	}else{
-		strcpy(filename_for_textbutton, filename);
+		path_length = strlen(configure_get_finalized_directory());
+		type_length = 4; //.ogg
 	}
+		
+	for(i=path_length + 1; i < length-type_length; i++){
+		filename_for_textbutton[y] = temp[i];
+		y++;
+	}
+	filename_for_textbutton[y] = '\0';
 
 	ClutterActor *label = tangle_button_new_with_background_actor(clutter_texture_new_from_file(
 			"/opt/jammo/communitymenu/community_cdlabel_small.png", NULL));
@@ -197,6 +193,10 @@ gboolean mysongs_add_loop_to_list(char* filename, int type)
 	textButton = tangle_button_new_with_background_actor(text);
 	clutter_actor_set_name(textButton,filename);
 
+	clutter_text_set_editable (CLUTTER_TEXT(text), FALSE);
+	clutter_text_set_max_length (CLUTTER_TEXT(text), 99);
+	clutter_text_set_single_line_mode (CLUTTER_TEXT(text), TRUE);
+
 	ClutterActor *arrowImage = clutter_texture_new_from_file("/opt/jammo/communitymenu/community_rightarrow.png", NULL);
 
 	//Additinally of type, there can be another icon e.g. video missing, new comments
@@ -206,7 +206,7 @@ gboolean mysongs_add_loop_to_list(char* filename, int type)
 
 			clutter_actor_set_position(infoButton, 690, 1);
 
-			g_signal_connect (textButton, "clicked", G_CALLBACK (start_sequencer_with_this_file),NULL);
+			//g_signal_connect (textButton, "clicked", G_CALLBACK (start_sequencer_with_this_file),NULL);
 		}
 		else if(type == 1) {
 			infoButton = tangle_button_new_with_background_actor(clutter_texture_new_from_file(
@@ -220,11 +220,11 @@ gboolean mysongs_add_loop_to_list(char* filename, int type)
 			//clutter_actor_set_height(infoButton, clutter_actor_get_height(colorbar));
 			//g_signal_connect (textButton, "clicked", G_CALLBACK (jukebox_play_this),NULL); //TODO: implement	
 
-			g_signal_connect_swapped(CLUTTER_ACTOR(textButton), "clicked", G_CALLBACK(play_selected_loop), filename);
+			//g_signal_connect_swapped(CLUTTER_ACTOR(textButton), "clicked", G_CALLBACK(play_selected_loop), 
+				//					clutter_actor_get_name(textButton));
 
 			clutter_actor_set_position(label, 500, 15);
 			clutter_actor_set_position(video, 580, 15);
-
 		}
 		else {
 			infoButton = tangle_button_new_with_background_actor(clutter_texture_new_from_file(
@@ -256,17 +256,54 @@ gboolean mysongs_add_loop_to_list(char* filename, int type)
 	clutter_container_add_actor(listContainer, arrowImage);
 	
 	clutter_container_add_actor(listContainer, infoButton);
+	
+	g_signal_connect_swapped(textButton, "button-press-event", G_CALLBACK(song_name_press_action), textButton);
+	g_signal_connect_swapped(textButton, "button-release-event", G_CALLBACK(song_name_press_action), textButton);
 
 	g_signal_connect_swapped(label, "clicked", G_CALLBACK(show_song_label), filename);
 	g_signal_connect_swapped(video, "clicked", G_CALLBACK(show_music_video), filename);
-	g_signal_connect_swapped(CLUTTER_ACTOR(infoButton), "clicked", G_CALLBACK(mysongs_comment), 
-						clutter_actor_get_parent(infoButton));
+
+	if(type == 0){
+		clutter_actor_set_name(infoButton,filename);
+		g_signal_connect (CLUTTER_ACTOR(infoButton), "clicked", G_CALLBACK (start_sequencer_with_this_file), NULL);
+	}else if(type == 1){
+		g_signal_connect_swapped(CLUTTER_ACTOR(infoButton), "clicked", G_CALLBACK(mysongs_comment),clutter_actor_get_parent(infoButton));
+	}
 
 	clutter_container_add_actor(songlist, CLUTTER_ACTOR(listContainer));
 
 	return TRUE;
 }
 
+/*void mysongs_comment(ClutterActor *actor)
+{
+	GList *children = clutter_container_get_children(songlist); //Get list of actors
+	GList *node = children;
+
+	int index = 0;
+	int found = 0;
+	
+	while(node != NULL)
+	{
+		index++;
+
+		if(actor == node->data)
+		{
+			//TO-DO: Send song to JamMo Songs
+			printf("Found it. Index %d\n", index);
+			printf("Sending song to JamMo Songs...\n");
+
+			found = 1;
+			break;
+		}
+
+		node = node->next;
+	}
+
+	g_list_free(children);
+}*/
+
+
 void mysongs_comment(ClutterActor *actor)
 {
 	GList *children = clutter_container_get_children(songlist); //Get list of actors
@@ -281,7 +318,10 @@ void mysongs_comment(ClutterActor *actor)
 
 		if(actor == node->data)
 		{
+			//TO-DO: Send song to JamMo Songs
 			printf("Found it. Index %d\n", index);
+			printf("Sending song to JamMo Songs...\n");
+
 			found = 1;
 			break;
 		}
