@@ -23,7 +23,7 @@ Call this: sequencer_track_view_tune_width
 #include "../jammo-miditrack-view.h"
 #include "../jammo.h"
 #include "../jammo-cursor.h"
-#include "../save_helper.h"
+#include "../file_helper.h"
 #include "../jammo-mentor.h"
 
 #include "sequencer_track_view.h"
@@ -351,19 +351,7 @@ void fullsequencer_community_clicked (TangleButton* tanglebutton, gpointer none)
 	printf("fullsequencer: Community pressed. Doesn't do anything\n");
 }
 
-void fullsequencer_home_clicked (TangleButton* tanglebutton, gpointer none){
-	JammoSequencer* sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
 
-	jammo_sequencer_stop(sequencer);
-
-	gchar* meta_data = g_strdup_printf
-	("\"pitch\" : \"%s\",\n\"tempo\" : %d,\n",jammo_sequencer_get_pitch(sequencer),jammo_sequencer_get_tempo(sequencer));
-
-	//save composition will return filename, but we are not interested in
-//	g_free(save_composition("7-12/", jammo_get_actor_by_id("fullsequencer-container-for-tracks"),meta_data));
-	g_free(meta_data);
-	startmenu_goto_startmenu(NULL,NULL);
-}
 
 
 /*
@@ -391,12 +379,13 @@ void sequencer_track_view_tune_width() {
 	//Set static
 	number_of_slots = n_slots;
 
+	//CURSOR IS NOT USED
 	//CURSOR
-	gfloat width_of_area = number_of_slots*width_of_slot;
-	ClutterActor* cursor;
-	cursor = jammo_get_actor_by_id("fullsequencer_cursor");
-	if (cursor)
-		clutter_actor_set_size(cursor, width_of_area, 80.0); //width is important, height is not used
+//	gfloat width_of_area = number_of_slots*width_of_slot;
+//	ClutterActor* cursor;
+//	cursor = jammo_get_actor_by_id("fullsequencer_cursor");
+//	if (cursor)
+//		clutter_actor_set_size(cursor, width_of_area, 80.0); //width is important, height is not used
 }
 
 
