@@ -39,6 +39,8 @@ void sequencer_track_view_tune_width();
 ClutterActor* sequencer_track_view_add_backing_track(JammoTrack* track, gboolean muted, gfloat volume);
 ClutterActor* sequencer_track_view_add_with_type(gint track_view_type, gboolean muted, gfloat volume, gint optional_parameter);
 
+ClutterActor* sequencer_track_view_create_editing_track(gboolean muted, gfloat volume, gint e_type, gchar* name_of_track_view);
+ClutterActor* sequencer_track_view_create_instrument_track(gboolean muted, gfloat volume, gint instrument_type, gchar* name_of_track_view);
 //void sequencer_sequencer_track_view_remove_last();
 bool save_sequencer_state();
 
