@@ -4,10 +4,15 @@ License: GPLv2, read more from COPYING
 This file contains the functionality of Workshops menu.
  */
 #include <tangle.h>
-#include <glib-object.h>
-#include "workshops.h"
+#include <string.h>
 #include "communitymenu.h"
+#include "startmenu.h"
 #include "../jammo.h"
+#include "workshops.h"
+#include "community_utilities.h"
+
+#include "../../configure.h"
+#include "../file_helper.h"
 
 void start_workshops(){
 
@@ -31,3 +36,18 @@ void start_workshops(){
 		puts("can't find 'workshop-view' ");
 	
 }
+void workshop_goto_communitymenu(TangleButton *tanglebutton, gpointer none)
+{
+	start_communitymenu();
+}
+
+void workshop_goto_startmenu(TangleButton *tanglebutton, gpointer none)
+{
+	startmenu_goto_startmenu(tanglebutton, none);
+}
+
+gboolean workshop_mentor_clicked (TangleButton *tanglebutton, gpointer data)
+{
+	printf("mentor clicked\n");
+	return TRUE;
+}
