@@ -422,15 +422,17 @@ int main(int argc, char** argv) {
 	clutter_main();
 
 	g_object_unref(script);
-	g_object_unref(stylesheet);
+	if (stylesheet)
+		g_object_unref(stylesheet);
 	
 	jammo_meam_cleanup();
+	
+	// Logout before releasing directories, since saving of profile requires these directories
+	gems_profile_manager_logout();
+	
 	configure_release_directories();
 
 #ifdef NETWORKING_ENABLED
-	/* PM logout */
-	gems_profile_manager_logout();
-	
 	/* GEMS cleanup */
 	jammo_gems_cleanup();
 #endif
