@@ -82,8 +82,10 @@ gboolean verify_path(ClutterRectangle *rect, ClutterEvent *event, ClutterActor *
 gboolean on_box_enter(ClutterActor *box, ClutterEvent *event,
 		ClutterActor *emblem, gpointer data) {
 	ClutterModifierType etype = clutter_event_get_state(event);
+	#ifndef N900
 	if (etype != 256)
 		return FALSE;
+	#endif
 
 	clutter_actor_set_opacity(emblem, 254);
 	/*
