@@ -10,6 +10,7 @@
 #include "screens.h"
 #include "../jammo.h"
 #include "../../cem/cem.h"
+#include "../../gems/gems.h"
 
 gint countChar(gchar *string, gchar c, int length) {
 	int retval = 0;
@@ -181,7 +182,15 @@ gboolean pg_validate_passwd(ClutterActor *stage, gchar *password, int is_new) {
 		cem_add_to_log(message, J_LOG_DEBUG);
 		g_free(message);
 
-		switch(gems_profile_manager_authenticate_default_user(password))
+		gchar* loginname = gems_get_login_username();
+		gboolean freelogin = FALSE;
+		if(!loginname)
+		{
+			freelogin = TRUE;
+			loginname = g_strdup("defaultuser");
+		}
+
+		switch(gems_profile_manager_authenticate_user(loginname,password))
 		{
 			// No profile installed (for defaultuser)
 			case LOGIN_NO_PROFILE:
@@ -194,6 +203,7 @@ gboolean pg_validate_passwd(ClutterActor *stage, gchar *password, int is_new) {
 				{
 					clutter_actor_show(jammo_get_actor_by_id("main-menu-view"));
 					clutter_actor_hide(jammo_get_actor_by_id("pen-gesture-view"));
+					if(freelogin) g_free(loginname);
 					return TRUE;
 				}
 				// This shouldn't really happen since a default profile with
@@ -201,6 +211,7 @@ gboolean pg_validate_passwd(ClutterActor *stage, gchar *password, int is_new) {
 				else
 				{
 					pg_set_error_screen(stage, PG_PASSWORD_ERROR);
+					if(freelogin) g_free(loginname);
 					return TRUE;
 				}
 			
@@ -208,11 +219,13 @@ gboolean pg_validate_passwd(ClutterActor *stage, gchar *password, int is_new) {
 			case LOGIN_OK:
 				clutter_actor_show(jammo_get_actor_by_id("main-menu-view"));
 				clutter_actor_hide(jammo_get_actor_by_id("pen-gesture-view"));
+				if(freelogin) g_free(loginname);
 				return TRUE;
 			
 			// Invalid password
 			case LOGIN_INVALID_PASSWORD:
 				pg_set_error_screen(stage, PG_PASSWORD_ERROR);
+				if(freelogin) g_free(loginname);
 				return TRUE;
 			
 			// Errorcases ...
@@ -225,6 +238,7 @@ gboolean pg_validate_passwd(ClutterActor *stage, gchar *password, int is_new) {
 			default:
 				// Go to error screen if other error occurs
 				pg_set_error_screen(stage, PG_PASSWORD_ERROR);
+				if(freelogin) g_free(loginname);
 				return TRUE;
 		}
 
@@ -234,6 +248,7 @@ gboolean pg_validate_passwd(ClutterActor *stage, gchar *password, int is_new) {
 		} else {
 			pg_set_error_screen(stage, PG_PASSWORD_ERROR);
 		}
+		if(freelogin) g_free(loginname);
 		return TRUE;
 	}
 }
