@@ -166,7 +166,17 @@ guint32 ProfileManager::GetId()
 
 gboolean ProfileManager::loadEncryptedProfile(gchar* _username)
 {
-	if(iStorageAgent->isProfileLoaded()) return TRUE; // TODO check if user is the same as previously loaded!
+	if(iStorageAgent->isProfileLoaded())
+	{
+		// Requesting same user
+		if(g_strcmp0(_username,iStorageAgent->getLoadedUser()) == 0) return TRUE;
+		// User changed, clear previous data
+		else 
+		{
+			iStorageAgent->clearEncryptedData();
+			iStorageAgent->clearDetails();
+		}
+	}
 	
 	switch(iStorageAgent->readProfile(_username))
 	{
@@ -239,6 +249,12 @@ gchar* ProfileManager::serializeProfile()
 	return iStorageAgent->serializeProfile();
 }
 
+gchar* ProfileManager::getLoadedUsername()
+{
+	if(iStorageAgent->isProfileLoaded()) return iStorageAgent->getLoadedUser();
+	else return NULL;
+}
+
 guchar* ProfileManager::getSalt()
 {
 	return iStorageAgent->getSalt();
@@ -331,24 +347,28 @@ ProfileManager* profilemanager_new_manager()
 // Delete manager object
 void profilemanager_delete_manager(ProfileManager* _aManager)
 {
-	delete _aManager;
+	if(_aManager) delete _aManager;
 }
 
 // Login to manager (no auth checking yet)
 gboolean profilemanager_login(ProfileManager* _aManager, guint32 _userId)
 {
+	if(_aManager == NULL) return FALSE;
 	return _aManager->Login(_userId);
 }
 
 // Logout from manager
 gboolean profilemanager_logout(ProfileManager* _aManager)
 {
+	if(_aManager == NULL) return FALSE;
 	return _aManager->Logout();
 }
 
 // View one information
 const gchar* profilemanager_view_info(ProfileManager* _aManager, gchar* _parameter)
 {
+	if(_aManager == NULL) return NULL;
+	
 	string param = string(_parameter);
 	return (_aManager->ViewDetail(param)).c_str();
 }
@@ -356,6 +376,7 @@ const gchar* profilemanager_view_info(ProfileManager* _aManager, gchar* _paramet
 // Edit own info
 gboolean profilemanager_edit_info(ProfileManager* _aManager, gchar* _parameter, gchar* _value)
 {
+	if(_aManager == NULL) return FALSE;
 	string param = string(_parameter);
 	string value = string(_value);
 	return _aManager->EditDetails(param,value);
@@ -363,12 +384,15 @@ gboolean profilemanager_edit_info(ProfileManager* _aManager, gchar* _parameter,
 
 guint32 profilemanager_get_userid(ProfileManager* _aManager)
 {
+	if(_aManager == NULL) return 0;
 	return _aManager->GetId();
 }
 
 // Get own username
 const gchar* profilemanager_get_username(ProfileManager* _aManager)
 {
+	if(_aManager == NULL) return NULL;
+	
 	string param = string(PROF_PARAM_USERNAME);
 	return (_aManager->ViewDetail(param)).c_str();
 }
@@ -376,6 +400,8 @@ const gchar* profilemanager_get_username(ProfileManager* _aManager)
 // Get first name
 const gchar* profilemanager_get_firstname(ProfileManager* _aManager)
 {
+	if(_aManager == NULL) return NULL;
+	
 	string param = string(PROF_PARAM_FIRSTNAME);
 	return (_aManager->ViewDetail(param)).c_str();
 }
@@ -383,6 +409,8 @@ const gchar* profilemanager_get_firstname(ProfileManager* _aManager)
 // Get last name
 const gchar* profilemanager_get_lastname(ProfileManager* _aManager)
 {
+	if(_aManager == NULL) return NULL;
+	
 	string param = string(PROF_PARAM_LASTNAME);
 	return (_aManager->ViewDetail(param)).c_str();
 }
@@ -390,12 +418,16 @@ const gchar* profilemanager_get_lastname(ProfileManager* _aManager)
 // Get age
 guint16 profilemanager_get_age(ProfileManager* _aManager)
 {
+	if(_aManager == NULL) return 0;
+	
 	string param = string(PROF_PARAM_AGE);
 	return atoi((_aManager->ViewDetail(param)).c_str());
 }
 
 guint32 profilemanager_get_points(ProfileManager* _aManager)
 {
+	if(_aManager == NULL) return 0;
+	
 	string param = string(PROF_PARAM_POINTS);
 	return (guint32)strtoul((_aManager->ViewDetail(param)).c_str(),NULL,10);
 }
@@ -403,12 +435,16 @@ guint32 profilemanager_get_points(ProfileManager* _aManager)
 /* Get avatar id */
 guint32 profilemanager_get_avatarid(ProfileManager* _aManager)
 {
+	if(_aManager == NULL) return 0;
+	
 	string param = string(PROF_PARAM_AVATARID);
 	return (guint32)strtoul((_aManager->ViewDetail(param)).c_str(),NULL,10);
 }
 
 gboolean profilemanager_set_username(ProfileManager* _aManager, gchar* _value)
 {
+	if(_aManager == NULL) return FALSE;
+	
 	string param = string(PROF_PARAM_USERNAME);
 	string value = string(_value);
 	return _aManager->EditDetails(param,value);
@@ -416,6 +452,8 @@ gboolean profilemanager_set_username(ProfileManager* _aManager, gchar* _value)
 
 gboolean profilemanager_set_firstname(ProfileManager* _aManager, gchar* _value)
 {
+	if(_aManager == NULL) return FALSE;
+	
 	string param = string(PROF_PARAM_FIRSTNAME);
 	string value = string(_value);
 	return _aManager->EditDetails(param,value);
@@ -423,6 +461,8 @@ gboolean profilemanager_set_firstname(ProfileManager* _aManager, gchar* _value)
 
 gboolean profilemanager_set_lastname(ProfileManager* _aManager, gchar* _value)
 {
+	if(_aManager == NULL) return FALSE;
+	
 	string param = string(PROF_PARAM_LASTNAME);
 	string value = string(_value);
 	return _aManager->EditDetails(param,value);
@@ -430,6 +470,8 @@ gboolean profilemanager_set_lastname(ProfileManager* _aManager, gchar* _value)
 
 gboolean profilemanager_set_age(ProfileManager* _aManager, guint16 _value)
 {
+	if(_aManager == NULL) return FALSE;
+	
 	stringstream strvalue;
 	string param = string(PROF_PARAM_AGE);
 	
@@ -443,6 +485,8 @@ gboolean profilemanager_set_age(ProfileManager* _aManager, guint16 _value)
 
 gboolean profilemanager_set_avatarid(ProfileManager* _aManager, guint32 _value)
 {
+	if(_aManager == NULL) return FALSE;
+	
 	string param = string(PROF_PARAM_AVATARID);
 	
 	stringstream strvalue;
@@ -455,6 +499,8 @@ gboolean profilemanager_set_avatarid(ProfileManager* _aManager, guint32 _value)
 
 gboolean profilemanager_add_points(ProfileManager* _aManager, guint32 _value)
 {
+	if(_aManager == NULL) return FALSE;
+	
 	string param = string(PROF_PARAM_POINTS);
 	guint32 points = (guint32)strtoul((_aManager->ViewDetail(param)).c_str(),NULL,10);
 	
@@ -470,6 +516,8 @@ gboolean profilemanager_add_points(ProfileManager* _aManager, guint32 _value)
 
 gboolean profilemanager_remove_points(ProfileManager* _aManager, guint32 _value)
 {
+	if(_aManager == NULL) return FALSE;
+	
 	string param = string(PROF_PARAM_POINTS);
 	guint32 points = (guint32)strtoul((_aManager->ViewDetail(param)).c_str(),NULL,10);
 	
@@ -486,6 +534,8 @@ gboolean profilemanager_remove_points(ProfileManager* _aManager, guint32 _value)
 
 void profilemanager_reset_points(ProfileManager* _aManager)
 {
+	if(_aManager == NULL) return;
+	
 	string param = string(PROF_PARAM_POINTS);
 	string value = "0";
 	_aManager->EditDetails(param,value);
@@ -493,16 +543,19 @@ void profilemanager_reset_points(ProfileManager* _aManager)
 
 gboolean profilemanager_storage_load_profile(ProfileManager* _aManager, gchar* _username)
 {
+	if(_aManager == NULL) return FALSE;
 	return _aManager->loadEncryptedProfile(_username);
 }
 
 gboolean profilemanager_storage_save_profile(ProfileManager* _aManager)
 {
+	if(_aManager == NULL) return FALSE;
 	return _aManager->saveEncryptedProfile();
 }
 
 gboolean profilemanager_storage_change_profile(ProfileManager* _aManager, gchar* _username)
 {
+	if(_aManager == NULL) return FALSE;
 	return _aManager->changeLoadedUser(_username);
 }
 
@@ -538,40 +591,54 @@ guint profilemanager_storage_get_encrypted_profile_size(ProfileManager* _aManage
 
 gboolean profilemanager_storage_set_password_salt(ProfileManager* _aManager, guchar* _salt)
 {
+	if(_aManager == NULL) return FALSE;
 	return _aManager->setSalt(_salt);
 }
 
 gboolean profilemanager_storage_set_password_hash(ProfileManager* _aManager, guchar* _hash)
 {
+	if(_aManager == NULL) return FALSE;
 	return _aManager->setPasswordHash(_hash);
 }
 
 gboolean profilemanager_storage_set_encrypted_profile(ProfileManager* _aManager, guchar* _profile_hash, guchar* _encrypted_profile, guint _e_profile_size)
 {
+	if(_aManager == NULL) return FALSE;
 	return _aManager->setEncryptedProfile(_profile_hash, _encrypted_profile, _e_profile_size);
 }
 
 gboolean profilemanager_storage_deserialize_profile(ProfileManager* _aManager, guchar* _profile)
 {
+	if(_aManager == NULL) return FALSE;
 	return _aManager->deserializeProfile((gchar*)_profile);
 }
 
 gchar* profilemanager_storage_serialize_profile(ProfileManager* _aManager)
 {
+	if(_aManager == NULL) return NULL;
 	return _aManager->serializeProfile();
 }
 
 gboolean profilemanager_set_authenticated(ProfileManager* _aManager)
 {
+	if(_aManager == NULL) return FALSE;
 	return _aManager->setAuthenticated();
 }
 
 gboolean profilemanager_is_authenticated(ProfileManager* _aManager)
 {
+	if(_aManager == NULL) return FALSE;
 	return _aManager->isAuthenticated();
 }
 gboolean profilemanager_is_saving_required(ProfileManager* _aManager)
 {
+	if(_aManager == NULL) return FALSE;
 	return _aManager->isSavingRequired();
 }
 
+gchar* profilemanager_get_loaded_username(ProfileManager* _aManager)
+{
+	if(_aManager == NULL) return NULL;
+	return _aManager->getLoadedUsername();
+}
+
