@@ -51,6 +51,7 @@ public:
 	gboolean deserializeProfile(gchar* _profile);
 	gchar* serializeProfile();
 	
+	gchar* getLoadedUsername();
 	guchar* getSalt();
 	guchar* getPasswordHash();
 	guchar* getProfileHash();
@@ -236,6 +237,7 @@ gboolean profilemanager_set_authenticated(ProfileManager* _aManager);
 gboolean profilemanager_is_authenticated(ProfileManager* _aManager);
 
 gboolean profilemanager_is_saving_required(ProfileManager* _aManager);
+gchar* profilemanager_get_loaded_username(ProfileManager* _aManager);
 #ifdef __cplusplus
 }
 #endif
