@@ -33,6 +33,7 @@ using namespace std;
 // Constructor
 StorageAgent::StorageAgent()
 {
+	loadeduser = NULL;
 	salt = NULL;
 	password_hash = NULL;
 	profile_hash = NULL;
@@ -374,6 +375,11 @@ gchar* StorageAgent::serializeProfile()
 	return c_serialized;
 }
 
+gchar* StorageAgent::getLoadedUser()
+{
+	return loadeduser;
+}
+
 guchar* StorageAgent::getSalt()
 {
 	return salt;
@@ -451,6 +457,12 @@ gboolean StorageAgent::setEncryptedProfile(guchar* _profile_hash, guchar* _encry
 
 void StorageAgent::clearEncryptedData()
 {
+	if(loadeduser != NULL)
+	{
+		g_free(loadeduser);
+		loadeduser = NULL;
+	}
+	
 	if(salt != NULL)
 	{
 		g_free(salt);
@@ -519,34 +531,43 @@ gint StorageAgent::readProfile(gchar* username)
 			cem_add_to_log(logmsg,J_LOG_DEBUG);
 			g_free(logmsg);
 			
+			// Free existing
+			if(salt) g_free(salt);
+			
 			// Extract salt
 			salt = (guchar*)g_malloc(sizeof(guchar*) * AES_SALT_LENGTH);
 			memset(salt,0,AES_SALT_LENGTH);
 			*(guint32*)&salt[0] = *(guint32*)&contents[0];
 			*(guint32*)&salt[sizeof(guint32)] = *(guint32*)&contents[sizeof(guint32)];
-			//*salt = slt;
+			
+			// Free existing
+			if(password_hash) g_free(password_hash);
 			
 			// Extract password hash
 			password_hash = (guchar*)g_malloc(sizeof(guchar*) * (SHA_HASH_LENGTH + 1));
 			memset(password_hash,0,SHA_HASH_LENGTH + 1);
 			g_memmove(password_hash,&contents[AES_SALT_LENGTH],SHA_HASH_LENGTH);
-			//*pw_hash = pw;
+			
+			// Free existing
+			if(profile_hash) g_free(profile_hash);
 			
 			// Extract profile hash
 			profile_hash = (guchar*)g_malloc(sizeof(guchar*) * (SHA_HASH_LENGTH + 1));
 			memset(profile_hash,0,SHA_HASH_LENGTH + 1);
 			g_memmove(profile_hash,&contents[AES_SALT_LENGTH + SHA_HASH_LENGTH],SHA_HASH_LENGTH);
-			//*profile_hash = p_hash;
+			
+			// Free existing
+			if(encrypted_profile) g_free(encrypted_profile);
 			
 			// Extract encrypted profile
 			encrypted_profile_size = length - SHA_HASH_LENGTH - SHA_HASH_LENGTH - AES_SALT_LENGTH;
 			encrypted_profile = (guchar*)g_malloc(sizeof(guchar*) * (encrypted_profile_size));
 			memset(encrypted_profile,0,encrypted_profile_size);
 			g_memmove(encrypted_profile,&contents[AES_SALT_LENGTH + SHA_HASH_LENGTH + SHA_HASH_LENGTH],encrypted_profile_size);
-			//*enc_profile = p_enc;
-			
-			// Profile length
-			//*enc_length = e_len;
+	
+			// copy the username
+			if(loadeduser) g_free(loadeduser);
+			loadeduser = g_strdup(username);
 
 			profileloaded = TRUE;
 		}
