@@ -1183,6 +1183,7 @@ void gems_communication_process_error(gems_connection* element)
 	gems_message* msg = NULL;
 	gchar* logmsg = NULL;
 	gems_connection* owner_elem = NULL;
+	gems_teacher_connection* tc = NULL;
 	
 	switch(element->connection_state)
 	{
@@ -1198,6 +1199,35 @@ void gems_communication_process_error(gems_connection* element)
 							break;
 						case ERROR_INVALID_ACCESS_TYPE:
 							break;
+						/* This should be reached only when user requests a specific username,
+						   if teacher has set a login name this should be never received*/
+						case ERROR_NO_PROFILE_FOR_USERNAME_TYPE:
+							tc = gems_get_teacher_connection();
+	
+							// Connection to teacher exists
+							if(tc)
+							{
+								// Is connected
+								if(ph_c_connection_is_connected(tc->connection->connection) == TRUE)
+								{
+									// Message is coming from teacher
+									if(ph_c_connection_get_device_checksum(tc->connection->connection) == ph_c_connection_get_device_checksum(element->connection))
+									{
+										// At least one request was made
+										if(gems_get_teacher_profile_request_count() > 0)
+										{
+											if(gems_get_data()->profile_request_timeout_sid != 0) g_source_remove(gems_get_data()->profile_request_timeout_sid);
+											if(gems_get_data()->teacher_profile_request_timer) g_timer_destroy(gems_get_data()->teacher_profile_request_timer);
+											gems_unset_waiting_for_teacher();
+										
+											cem_add_to_log("gems_communication_process_error: No profile for requested username on teacher server",J_LOG_NETWORK_DEBUG);
+										
+											// TODO add callback to CHUM : profile not found
+										}
+									}
+								}
+							}
+							break;
 						default:
 							break;
 					}
