@@ -53,6 +53,11 @@ gems_components* gems_get_data()
 		gems_data->connection_errorlist = NULL;
 		gems_data->service_collaboration = NULL;
 		gems_data->teacher_connection = NULL;
+		gems_data->teacher_profile_request_timer = NULL;
+		gems_data->profile_request_timeout_sid = 0;
+		gems_data->teacher_profile_requests = 0;
+		gems_data->waiting_for_teacher = FALSE;
+		gems_data->username_to_login = NULL;
 	}
 	return gems_data;
 }
@@ -133,6 +138,65 @@ gems_teacher_connection* gems_get_teacher_connection()
 	return gems_get_data()->teacher_connection;
 }
 
+gboolean gems_is_waiting_for_teacher()
+{
+	return gems_get_data()->waiting_for_teacher;
+}
+
+void gems_set_waiting_for_teacher()
+{
+	// TODO call CHUM to "draw the curtain"
+	gems_get_data()->waiting_for_teacher = TRUE;
+}
+
+void gems_unset_waiting_for_teacher()
+{
+	// TODO call CHUM to "remove curtain"
+	gems_get_data()->waiting_for_teacher = FALSE;
+	gems_reset_teacher_profile_request_counter();
+}
+
+void gems_unset_teacher_timeout_sid(gpointer param)
+{
+	cem_add_to_log("Unset teacher timeout",J_LOG_NETWORK_DEBUG);
+	gems_get_data()->profile_request_timeout_sid = 0;
+	gems_reset_teacher_profile_request_counter();
+}
+
+void gems_increase_teacher_profile_request_counter()
+{
+	gems_get_data()->teacher_profile_requests++;
+}
+
+void gems_reset_teacher_profile_request_counter()
+{
+	gems_get_data()->teacher_profile_requests = 0;
+}
+
+guint gems_get_teacher_profile_request_count()
+{
+	return gems_get_data()->teacher_profile_requests;
+}
+
+void gems_set_login_username(gchar* username)
+{
+	gems_get_data()->username_to_login = g_strdup(username);
+}
+
+gchar* gems_get_login_username()
+{
+	return gems_get_data()->username_to_login;
+}
+
+void gems_clear_login_username()
+{
+	if(gems_get_data()->username_to_login)
+	{
+		g_free(gems_get_data()->username_to_login);
+		gems_get_data()->username_to_login = NULL;
+	}
+}
+
 gboolean gems_teacher_connection_is_connected()
 {
 	if(gems_get_teacher_connection() != NULL)
@@ -315,6 +379,15 @@ void jammo_gems_cleanup()
 		gems_service_mentor_cleanup();
 	}
 	
+	// Clear the profile request timer
+	if(components->teacher_profile_request_timer)
+	{
+		g_timer_destroy(components->teacher_profile_request_timer);
+		components->teacher_profile_request_timer = NULL;
+	}
+	
+	if(components->profile_request_timeout_sid != 0) g_source_remove(components->profile_request_timeout_sid);
+	if(components->username_to_login) g_free(components->username_to_login);
 	gems_clear_teacher_connection();
 	
 	// delete peerhood
