@@ -52,6 +52,16 @@ gems_service_mentor* gems_get_service_mentor();
 gems_teacher_connection* gems_get_teacher_connection();
 gboolean gems_teacher_connection_is_connected();
 
+gboolean gems_is_waiting_for_teacher();
+void gems_set_waiting_for_teacher();
+void gems_unset_waiting_for_teacher();
+void gems_unset_teacher_timeout_sid(gpointer param);
+void gems_increase_teacher_profile_request_counter();
+void gems_reset_teacher_profile_request_counter();
+guint gems_get_teacher_profile_request_count();
+void gems_set_login_username(gchar* username);
+gchar* gems_get_login_username();
+void gems_clear_login_username();
 GList* gems_get_errorlist();
 
 void gems_list_profile_parameters();//Testing only
