@@ -54,7 +54,7 @@ typedef enum
 // Group adverting interval, 3 seconds
 #define GROUP_ADVERT_INTERVAL 3.00
 // Limit for removing group (from last advert)
-#define GROUP_REMOVE_LIMIT 60.00
+#define GROUP_REMOVE_LIMIT 4*GROUP_ADVERT_INTERVAL
 // Limit for removing from rejected list - 5 min
 #define REJECTED_LIST_REMOVE_LIMIT 300.00
 // Limit for errorous connections
@@ -67,6 +67,9 @@ typedef enum
 #define FREE_SLOT 0
 // Group not active
 #define NOT_ACTIVE 0
+// Timer limit for teacher profile requests
+#define TEACHER_PROFILE_REQUEST_LIMIT 2.00
+#define TEACHER_PROFILE_REQUEST_MAX_COUNT 2
 
 // Used as return values when searching connections from various lists
 #define NOT_IN_LIST 0
@@ -240,6 +243,7 @@ typedef enum
 #define ERROR_NOT_GROUP_OWNER_TYPE 10014
 
 #define ERROR_INVALID_ACCESS_TYPE 10036
+#define ERROR_NO_PROFILE_FOR_USERNAME_TYPE 10037
 
 #define ERROR_ALREADY_CONNECTED_MSG "Already connected or trying to connect."
 #define ERROR_VERSION_MISMATCH_MSG "Versions mismatch."
@@ -257,6 +261,7 @@ typedef enum
 #define ERROR_NOT_GROUP_OWNER_MSG "Not the owner of the group."
 
 #define ERROR_INVALID_ACCESS_MSG "Not enough privileges to get full profile"
+#define ERROR_NO_PROFILE_FOR_USERNAME_MSG "No profile exists for requested username."
 
 /*----------- PROFILE MANAGER ----------*/
 #define JAMMOPROFILE "profiles"
@@ -288,6 +293,11 @@ typedef enum
 #define LOGIN_INVALID_PASSWORD 4
 #define LOGIN_PROFILE_HASH_FAIL 5
 #define LOGIN_PROFILE_CORRUPT 6
+#define CHANGE_USER_OK 0
+#define CHANGE_USER_WAITING_PROFILE 1
+#define CHANGE_USER_LOGOUT_REQUIRED 2
+#define CHANGE_USER_NO_PROFILE -1
+#define CHANGE_USER_NO_USERNAME 3
 
 
 // Security vars
