@@ -49,7 +49,7 @@ gems_message* gems_create_error_message(gint16 errortype, gint16 serviceid)
 	*(gint16*)&errormsg->message[position] = g_htons(errortype); // Error type
 	position = position + sizeof(gint16);
 	
-	g_strlcat(&errormsg->message[position],get_errormessage(errortype),errormsg->length); // Error message
+	g_strlcat(&errormsg->message[position],get_errormessage(errortype),errormsg->length - position); // Error message
 	
 	return errormsg;
 }
@@ -110,7 +110,10 @@ gchar* get_errormessage(gint16 errortype)
 			
 		case ERROR_NOT_GROUP_OWNER_TYPE:
 			return ERROR_NOT_GROUP_OWNER_MSG;
-		
+			
+		case ERROR_NO_PROFILE_FOR_USERNAME_TYPE:
+			return ERROR_NO_PROFILE_FOR_USERNAME_MSG;
+			
 		default:
 			return ERROR_NO_ERROR;
 	}
@@ -144,7 +147,7 @@ gems_message* gems_create_message_service_jammo(gint16 type)
 	position = position + sizeof(gint16);
 	
 	// Adding version info
-	if(type == VERSION_REPLY) g_strlcat(&msg->message[position],VERSION,msg->length);
+	if(type == VERSION_REPLY) g_strlcat(&msg->message[position],VERSION,msg->length - position);
 	
 	return msg;
 }
@@ -174,7 +177,7 @@ gems_message* gems_create_message_service_profile(gint16 type)
 	msg->length = sizeof(gint16) + sizeof(gint32) + sizeof(gint16);
 	
 	// Public parts, basic header + username length + \0 + user id + age + avatar id
-	if(type == PROFILE_PUB) msg->length = msg->length + strlen(username) + 1 + sizeof(guint32) + sizeof(guint16) + sizeof(guint32);
+	msg->length = msg->length + strlen(username) + 1 + sizeof(guint32) + sizeof(guint16) + sizeof(guint32);
 	
 	// Full profile
 	if(type == PROFILE_FULL)
@@ -209,7 +212,7 @@ gems_message* gems_create_message_service_profile(gint16 type)
 	position = position + sizeof(gint16);
 	
 	// Username
-	g_strlcat(&msg->message[position],username,msg->length);
+	g_strlcat(&msg->message[position],username,msg->length - position);
 	position = position + strlen(username) + 1; //Add the '\0'
 	
 	// User id
@@ -232,12 +235,12 @@ gems_message* gems_create_message_service_profile(gint16 type)
 	else if(type == PROFILE_FULL)
 	{
 		// firstname
-		g_strlcat(&msg->message[position],fname,msg->length);
-		position = strlen(fname) + 1;
+		g_strlcat(&msg->message[position],fname,msg->length - position);
+		position = position + strlen(fname) + 1;
 		
 		// lastname
-		g_strlcat(&msg->message[position],lname,msg->length);
-		position = strlen(lname) + 1;
+		g_strlcat(&msg->message[position],lname,msg->length - position);
+		position = position + strlen(lname) + 1;
 		
 		// points
 		guint32 points = gems_profile_manager_get_points();
@@ -305,7 +308,7 @@ gems_message* gems_create_message_teacher_service_profile_request(gchar* usernam
 	position = position + sizeof(gint16);
 	
 	// Username
-	g_strlcat(&msg->message[position],username,strlen(username)+1);
+	g_strlcat(&msg->message[position],username,msg->length - position);
 	position = position + strlen(username) + 1;
 	
 	return msg;
@@ -338,7 +341,7 @@ gems_message* gems_create_message_teacher_service_profile_reply(gchar* data, gui
 	position = position + sizeof(gint16);
 	
 	// Username
-	g_strlcat(&msg->message[position],username,unamelen); 
+	g_strlcat(&msg->message[position],username,msg->length - position); 
 	position = position + unamelen;
 	
 	// Encrypted profile data
@@ -677,11 +680,11 @@ gems_message* gems_create_message_collaboration_action_vi_single(gint16 type, co
 	position = position + sizeof(gint16);
 	
 	// png_name TODO should this be id?
-	g_strlcat(&msg->message[position],png_name,msg->length);
+	g_strlcat(&msg->message[position],png_name,msg->length - position);
 	position = position + strlen(png_name)+1 ;
 
 	// wav_name TODO should this be id?
-	g_strlcat(&msg->message[position],wav_name,msg->length);
+	g_strlcat(&msg->message[position],wav_name,msg->length - position);
 	position = position + strlen(wav_name)+1 ;
 
 	// slot
@@ -719,7 +722,7 @@ gems_message* gems_create_message_collaboration_action_song_info(gint16 type, co
 	position = position + sizeof(gint16);
 	
 	// song_info
-	g_strlcat(&msg->message[position],song_info,msg->length);
+	g_strlcat(&msg->message[position],song_info,msg->length - position);
 	position = position + strlen(song_info)+1 ;
 
 	
@@ -1008,7 +1011,7 @@ gems_message* gems_create_message_control_set_login_name(gchar* username)
 	position = position + sizeof(gint16);
 	
 	// Username
-	g_strlcat(&msg->message[position],username,strlen(username)+1);
+	g_strlcat(&msg->message[position],username,msg->length - position);
 	position = position + strlen(username) + 1;
 	
 	return msg;
