@@ -103,7 +103,7 @@ gint gems_profile_manager_authenticate_user(gchar* username, gchar* passworddata
 	if(passlength != SHA_HASH_LENGTH) cem_add_to_log("Authentication might fail, password hash length is not 256 bits (32 bytes)!", J_LOG_ERROR);
 
 	// verify passwords
-	if(!gems_security_verify_hash(pwhash,profilemanager_storage_get_password_hash(pm)))
+	if(!gems_security_verify_hash(pwhash,profilemanager_storage_get_password_hash(pm),SHA_HASH_LENGTH))
 	{
 		cem_add_to_log("Authentication failure: invalid password", J_LOG_INFO);
 		if(passwd != NULL) g_free(passwd);
@@ -124,7 +124,7 @@ gint gems_profile_manager_authenticate_user(gchar* username, gchar* passworddata
 	if(decprofhashlength != SHA_HASH_LENGTH) cem_add_to_log("Authentication might fail, profile hash length is not 256 bits (32 bytes)!", J_LOG_ERROR);
 	
 	// verify profile hashes
-	if(!gems_security_verify_hash(decprofhash,profilemanager_storage_get_profile_hash(pm)))
+	if(!gems_security_verify_hash(decprofhash,profilemanager_storage_get_profile_hash(pm),SHA_HASH_LENGTH))
 	{
 		cem_add_to_log("Authentication failure: decrypted profile content differs from stored!", J_LOG_ERROR);
 		if(passwd != NULL) g_free(passwd);
@@ -161,24 +161,123 @@ gint gems_profile_manager_authenticate_user(gchar* username, gchar* passworddata
 	return LOGIN_OK;
 }
 
+gint gems_profile_manager_set_user(gchar* username)
+{
+	cem_add_to_log("gems_profile_manager_set_user",J_LOG_INFO);
+	// if authenticated, cannot change user before logout, logout clears also the loaded data and sets load check to FALSE
+	if(profilemanager_is_authenticated(gems_get_profile_manager())) return CHANGE_USER_LOGOUT_REQUIRED;
+	else 
+	{
+		// Was the request name set
+		if(gems_get_login_username() == NULL)
+		{
+			if(username) gems_set_login_username(username); // creates a duplicate so given can be free'd
+			else return CHANGE_USER_NO_USERNAME;
+		}
+		
+		// Profile does not exist
+		if(!profilemanager_storage_load_profile(gems_get_profile_manager(),gems_get_login_username()))
+		{
+			if(gems_get_data()->teacher_profile_request_timer)
+			{
+				// Not enough time spent
+				if(g_timer_elapsed(gems_get_data()->teacher_profile_request_timer,NULL) < TEACHER_PROFILE_REQUEST_LIMIT) return TRUE;
+			}
+			// create new timer
+			else gems_get_data()->teacher_profile_request_timer = g_timer_new(); // when first run this should be reached
+			
+			// New requests can be made & connection to teacher exists and request was sent
+			if((gems_get_teacher_profile_request_count() < TEACHER_PROFILE_REQUEST_MAX_COUNT) && 
+				(gems_communication_do_profile_request_to_teacher(gems_get_login_username())))
+			{
+				// set waiting for teacher - no logins should be possible!
+				gems_set_waiting_for_teacher();
+				gems_increase_teacher_profile_request_counter();
+				
+				// restart timer
+				g_timer_start(gems_get_data()->teacher_profile_request_timer);
+				
+				// Add timed function if not set
+				if(gems_get_data()->profile_request_timeout_sid == 0)
+				{
+					gems_get_data()->profile_request_timeout_sid = 
+						g_timeout_add_full(G_PRIORITY_HIGH,100,(GSourceFunc)gems_profile_manager_set_user, NULL, gems_unset_teacher_timeout_sid);
+				}
+				return CHANGE_USER_WAITING_PROFILE; // Equals TRUE, the timed function remains
+			}
+			
+			// no teacher or cannot send request or limit reached -> no profile for user
+			else
+			{
+				// Destroy timer and set to NULL
+				if(gems_get_data()->teacher_profile_request_timer)
+				{
+					g_timer_destroy(gems_get_data()->teacher_profile_request_timer);
+					gems_get_data()->teacher_profile_request_timer = NULL;
+				}
+				
+				// Make sure that source is removed
+				if(gems_get_data()->profile_request_timeout_sid != 0) g_source_remove(gems_get_data()->profile_request_timeout_sid);
+				gems_reset_teacher_profile_request_counter();
+				
+				// No profile for this username, clear it
+				gems_clear_login_username();
+				
+				return CHANGE_USER_NO_PROFILE;
+			}
+		}
+		// profile exists and is loaded
+		else
+		{
+			// Allow to continue
+			gems_unset_waiting_for_teacher();
+			
+			// Destroy timer and set to NULL
+			if(gems_get_data()->teacher_profile_request_timer)
+			{
+				g_timer_destroy(gems_get_data()->teacher_profile_request_timer);
+				gems_get_data()->teacher_profile_request_timer = NULL;
+			}
+			gems_reset_teacher_profile_request_counter();
+			
+			// Equals to FALSE (0) so the timeout function should be removed
+			return CHANGE_USER_OK;
+		}
+	}
+}
+
 gboolean gems_profile_manager_change_password(gchar* passworddata)
 {
 	gboolean rval = TRUE;
 	ProfileManager* pm = gems_get_profile_manager();
 	
+	if(!passworddata || !pm) return FALSE;
+	
+	// TODO allow only one change if new password is not sent to teacher!!
 	// Do not allow password change if not authenticated
 	if(profilemanager_is_authenticated(pm))
 	{
 		// Create salt and password
 		guchar* salt = gems_security_create_password_salt();
 		guchar* passwd = gems_security_create_password(passworddata,salt);
-		gems_security_change_password(passwd,salt);
 		
 		// Hash password
 		guint hashlen = PASSLEN;
 		guchar* passhash = gems_security_calculate_hash(passwd,&hashlen);
 		if(hashlen != SHA_HASH_LENGTH) cem_add_to_log("Next authentication might fail, password hash length is not 256 bits (32 bytes)!", J_LOG_ERROR);
 		
+		// TODO encrypt new password with current context
+		//guint encnewpwlen = strlen(passworddata);
+		//guchar* encnewpw = gems_security_encrypt_data((guchar*)passworddata,&encnewpwlen);
+		
+		// TODO decrypt the password
+		
+		// TODO hash decrypted and compare hashes
+		
+		
+		// Set new security contexts
+		gems_security_change_password(passwd,salt);
+		
 		// Set new salt and password
 		if(profilemanager_storage_set_password_salt(pm,salt) && profilemanager_storage_set_password_hash(pm,passhash))
 		{
@@ -204,7 +303,7 @@ gboolean gems_profile_manager_change_password(gchar* passworddata)
 			if(hashlength != SHA_HASH_LENGTH) cem_add_to_log("Next uthentication might fail, decrypted profile hash length is not 256 bits (32 bytes)!", J_LOG_ERROR);
 		
 			// Verify that the encryption and decryption works
-			if(gems_security_verify_hash(profilehash,decryptedhash))
+			if(gems_security_verify_hash(profilehash,decryptedhash,SHA_HASH_LENGTH))
 			{
 				// Set profile (encrypted with new password)
 				if(profilemanager_storage_set_encrypted_profile(pm,profilehash,encrypted,profilelength))
@@ -217,6 +316,9 @@ gboolean gems_profile_manager_change_password(gchar* passworddata)
 						cem_add_to_log("New encrypted profile not saved.", J_LOG_ERROR);
 					}
 				}
+				
+				// TODO Send passhash + encnewpw to teacher if teacher is present
+				// TODO If no teacher, the encnewpw (+ its length) should be saved somewhere for sending it later!
 			}
 			else
 			{
@@ -239,6 +341,7 @@ gboolean gems_profile_manager_change_password(gchar* passworddata)
 		if(salt != NULL) g_free(salt);
 		if(passwd != NULL) g_free(passwd);
 		if(passhash != NULL) g_free(passhash);
+		//if(encnewpw != NULL) g_free(encnewpw);
 	}
 	// Not authenticated
 	else
@@ -308,7 +411,7 @@ gboolean gems_profile_manager_logout()
 			if(hashlength != SHA_HASH_LENGTH) cem_add_to_log("Next authentication might fail, decrypted profile hash length is not 256 bits (32 bytes)!", J_LOG_ERROR);
 		
 			// Verify that the profile can be decrypted with same password
-			if(gems_security_verify_hash(profilehash,decryptedhash))
+			if(gems_security_verify_hash(profilehash,decryptedhash,SHA_HASH_LENGTH))
 			{
 				// Save the profile to file
 				if(profilemanager_storage_set_encrypted_profile(pm,profilehash,encrypted,profilelength))
@@ -336,6 +439,7 @@ gboolean gems_profile_manager_logout()
 	else cem_add_to_log("Not authenticated, nothing done for logout.", J_LOG_DEBUG);
 	
 	gems_security_clear_security();
+	gems_clear_login_username();
 	
 	return profilemanager_logout(pm);
 }
@@ -459,3 +563,11 @@ gboolean gems_profile_manager_is_authenticated()
 	
 	return profilemanager_is_authenticated(pm);
 }
+
+gchar* gems_profile_manager_get_loaded_username()
+{
+	ProfileManager* pm = gems_get_data()->pm;
+	if(pm == NULL) return NULL;
+	
+	return profilemanager_get_loaded_username(pm);
+}
