@@ -32,8 +32,8 @@ gems_message* gems_security_create_envelope(gint16 type,gems_connection* element
 	position = position + sizeof(gint32);
 	
 	// Hash /*Casting by Aapo, because of compile time warnings!*/
-	unsigned char* hash = SHA1((const unsigned char*)(original->message),(guint32)(original->length),NULL);
-	g_strlcat(&envelope->message[position],(char*)hash,envelope->length);
+	guchar* hash = SHA1((const guchar*)(original->message),(guint32)original->length,NULL);
+	g_memmove(&envelope->message[position],(gchar*)hash,JAMMO_MESSAGE_DIGEST_SIZE);
 	position = position + JAMMO_MESSAGE_DIGEST_SIZE + 1;
 	
 	// Copy original message
@@ -47,16 +47,20 @@ gint gems_security_extract_envelope(gems_connection* element)
 	// [id:2|lenght:4|hash|srvid:2|length:4|cmd:2|...]
 	gint32 length = ntohl(gems_connection_get_32(element,sizeof(gint16)));
 	
-	//gchar* hash =
-	gems_connection_get_data(element,sizeof(gint16)+sizeof(gint32),JAMMO_MESSAGE_DIGEST_SIZE);
+	guchar* storedhash = (guchar*)gems_connection_get_data(element,sizeof(gint16)+sizeof(gint32),JAMMO_MESSAGE_DIGEST_SIZE);
 	
 	memmove(&element->nwbuffer[0],
 		&element->nwbuffer[sizeof(gint16) + sizeof(gint32) + JAMMO_MESSAGE_DIGEST_SIZE + 1],
 		(length - sizeof(gint16) - sizeof(gint32) - JAMMO_MESSAGE_DIGEST_SIZE - 1));
 		
 	// TODO compare hashes
-	
-	return SECURITY_OK;
+	guchar* calchash = SHA1((const guchar*)(&(element->nwbuffer)),ntohl(gems_connection_get_32(element,sizeof(gint16))),NULL);
+	if(!gems_security_verify_hash(storedhash,calchash,JAMMO_MESSAGE_DIGEST_SIZE))
+	{
+		cem_add_to_log("gems_security_extract_envelope: message corrupt - hashes do not match!", J_LOG_NETWORK_DEBUG);
+		return SECURITY_CORRUPT_MESSAGE;
+	}
+	else return SECURITY_OK;
 }
 
 gboolean gems_security_init_security(guchar* password, guchar* salt)
@@ -307,10 +311,12 @@ guchar* gems_security_calculate_hash(guchar* data, guint* data_length)
 	return hash;
 }
 
-gboolean gems_security_verify_hash(guchar* hash1, guchar* hash2)
+gboolean gems_security_verify_hash(guchar* hash1, guchar* hash2, guint32 hashlength)
 {
 	if(hash1 == NULL || hash2 == NULL) return FALSE;
-	return (g_strcmp0((gchar*)hash1,(gchar*)hash2) == 0) ? TRUE : FALSE;
+	
+	for(guint i = 0; i < hashlength ; i++) if(hash1[i] != hash2[i]) return FALSE;
+	return TRUE;
 }
 
 // encryption context, data to encrypt, data length
