@@ -43,7 +43,7 @@ gboolean gems_security_init_sha(EVP_MD_CTX* md);
 guchar* gems_security_calculate_hash(guchar* data, guint* data_length);
 
 // Check that two given hashes match
-gboolean gems_security_verify_hash(guchar* hash1, guchar* hash2);
+gboolean gems_security_verify_hash(guchar* hash1, guchar* hash2,guint32 hashlength);
 
 // Encrypt given data with given encryption context
 guchar* gems_security_encrypt_data(guchar* profile_data, guint* data_length);
