@@ -135,7 +135,27 @@ void gems_service_control_handle_set_login(gems_components* data, gems_connectio
 	cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 	g_free(logmsg);
 	
-	// TODO set the loginname!
+	// if logged in, logout the user
+	if(gems_profile_manager_logout()) cem_add_to_log("gems_service_control_handle_set_login: logged out previous user",J_LOG_DEBUG);
+	
+	// load profile with loginname
+	switch(gems_profile_manager_set_user(loginname))
+	{
+		// Found & loaded
+		case CHANGE_USER_OK:
+			cem_add_to_log("gems_service_control_handle_set_login: profile found",J_LOG_DEBUG);
+			break;
+		// Not found but request sent
+		case CHANGE_USER_WAITING_PROFILE:
+			cem_add_to_log("gems_service_control_handle_set_login: profile requested.",J_LOG_DEBUG);
+			break;
+		// Should not happen!
+		case CHANGE_USER_NO_USERNAME:
+			cem_add_to_log("gems_service_control_handle_set_login: teacher sent username as NULL.",J_LOG_DEBUG);
+			break;
+		default:
+			break;
+	}
 	
 	g_free(loginname);
 }
