@@ -559,7 +559,7 @@ gboolean gems_service_jammo_process_error(gems_connection *element, gboolean ser
 				cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 				g_free(logmsg);
 				success = FALSE; // remove this connection in gems_service_jammo_process_list
-				data->connection_errorlist = gems_connection_error_add(data->connection_errorlist,ph_c_connection_get_device_checksum(element->connection), ERROR_ALREADY_CONNECTED);
+				//data->connection_errorlist = gems_connection_error_add(data->connection_errorlist,ph_c_connection_get_device_checksum(element->connection), ERROR_ALREADY_CONNECTED);
 				break;
 			case ERROR_VERSION_MISMATCH_TYPE:
 				logmsg = g_strdup_printf("gems_service_jammo_process_error: ERROR_VERSION_MISMATCH ");
