@@ -402,6 +402,20 @@ void gems_connection_localize_data_in_buffer(gems_connection* element)
 					gems_connection_add_32(element, g_ntohl(gems_connection_get_32(element,element->add_position)));
 					break;
 				case PROFILE_FULL:
+					// Username -> add_position = add_position + Username length + tailing '\0'
+					element->add_position = element->add_position + strlen(gems_connection_get_char(element,element->add_position)) + 1;
+					// User id
+					gems_connection_add_32(element, g_ntohl(gems_connection_get_32(element,element->add_position)));
+					// age
+					gems_connection_add_16(element, g_ntohs(gems_connection_get_16(element,element->add_position)));
+					// avatar id
+					gems_connection_add_32(element, g_ntohl(gems_connection_get_32(element,element->add_position)));
+
+					// firstname and lastname
+					element->add_position = element->add_position + strlen(gems_connection_get_char(element,element->add_position)) + 1;
+					element->add_position = element->add_position + strlen(gems_connection_get_char(element,element->add_position)) + 1;
+					// points
+					gems_connection_add_32(element, g_ntohl(gems_connection_get_32(element,element->add_position)));
 					break;
 				case REQ_ENC_PROFILE:
 					// Should contain username after 16+32+16 bits, no conversion
