@@ -217,7 +217,7 @@ gboolean gems_teacher_server_encrypt_profile(jammo_profile_container* container)
 			decprofhash = gems_security_calculate_hash(decprofile,&hashlen);
 			if(hashlen != SHA_HASH_LENGTH) rval = FALSE; // Invalid size hash, profile might not be valid
 		
-			if(gems_security_verify_hash(profilehash,decprofhash))
+			if(gems_security_verify_hash(profilehash,decprofhash,SHA_HASH_LENGTH))
 			{
 				container->encrypted_length = AES_SALT_LENGTH + 32 + 32 + profilelen;
 				
@@ -598,7 +598,7 @@ gboolean gems_teacher_server_encrypt_profiles(teacher_server_profile_data* data,
 		if(hash_length != SHA_HASH_LENGTH) rval = FALSE; // Invalid size hash, profile might not be valid
 	
 		// verify hashes
-		if(!gems_security_verify_hash(data->datahash,dechash)) rval = FALSE;
+		if(!gems_security_verify_hash(data->datahash,dechash,SHA_HASH_LENGTH)) rval = FALSE;
 		gems_security_clear_security();
 	}
 	else rval = FALSE;
@@ -636,7 +636,7 @@ gboolean gems_teacher_server_decrypt_profiles(teacher_server_profile_data* data,
 		if(hashlength != SHA_HASH_LENGTH) rval = FALSE;
 		
 		// password verified
-		if(gems_security_verify_hash(pwhash,data->pwhash))
+		if(gems_security_verify_hash(pwhash,data->pwhash,SHA_HASH_LENGTH))
 		{
 			// decrypt
 			decrypted = gems_security_decrypt_data(data->data,&(data->datalength));
@@ -647,7 +647,7 @@ gboolean gems_teacher_server_decrypt_profiles(teacher_server_profile_data* data,
 			if(hashlength != SHA_HASH_LENGTH) rval = FALSE;
 			
 			// verify hash
-			if(gems_security_verify_hash(data->datahash,dechash))
+			if(gems_security_verify_hash(data->datahash,dechash,SHA_HASH_LENGTH))
 			{
 				if(data->profiles != NULL)
 				{
