@@ -788,7 +788,7 @@ static void do_playback_process(GstJammoSampler * src){
 	timestamp = event->timestamp;
 
 	while (src->time * src->tempo_scale > timestamp){
-		printf("DEBUG: gstjammosampler: delayed: %llu ms\n",(unsigned long long) ((src->time * src->tempo_scale - timestamp)/src->tempo_scale)/1000/1000);
+		//printf("DEBUG: gstjammosampler: delayed: %llu ms\n",(unsigned long long) ((src->time * src->tempo_scale - timestamp)/src->tempo_scale)/1000/1000);
 		int note=event->note + src->pitch_shift;
 
 		//note is unsigned.
@@ -1036,7 +1036,7 @@ static gboolean gst_jammo_sampler_start (GstBaseSrc * basesrc)
   GstJammoSampler *src = GST_JAMMO_SAMPLER (basesrc);
   int i;
 
-  printf("DEBUG:gstjammosampler: jammo_sampler_starts\n");
+  //printf("DEBUG:gstjammosampler: jammo_sampler_starts\n");
 
   src->next_sample = 0;
   src->next_byte = 0;
@@ -1051,19 +1051,20 @@ static gboolean gst_jammo_sampler_start (GstBaseSrc * basesrc)
 
   //realtime recording
   if (src->recording) {
-    printf("DEBUG:gstjammosampler: recording mode\n");
+    //printf("DEBUG:gstjammosampler: recording mode\n");
     src->eventlist=NULL;
     src->creation_time = gst_clock_get_time(gst_system_clock_obtain()); //time just now
     src->playback_not_started=TRUE;
   }
   //playback
   else  {
-    printf("DEBUG:gstjammosampler: not recording, playback\n");
+    //printf("DEBUG:gstjammosampler: not recording, playback\n");
 
     //src->playback_starting_time = gst_clock_get_time(gst_system_clock_obtain());
     src->playback_not_started=FALSE;
     src->playback_index_for_event=0;
 
+    /*
     //Test:
    GList* list;
    JammoMidiEvent* n;
@@ -1073,6 +1074,7 @@ static gboolean gst_jammo_sampler_start (GstBaseSrc * basesrc)
       printf("TEST:gstjammosampler:In stack: %llu ms: note:%d ,type: %s \n", (unsigned long long)n->timestamp/1000/1000
             ,n->note,n->type==JAMMOMIDI_NOTE_ON? "start":"stop");
    }
+   */
   }
 
 
@@ -1560,7 +1562,7 @@ gst_jammo_sampler_set_property (GObject * object, guint prop_id,
 
 			//realtime. There are no timestamp in event, use current time
 			if (src->recording){
-			printf("realtime\n");
+			//printf("realtime\n");
 			GstClockTime timestamp;
 			timestamp = src->time * src->tempo_scale;
 
@@ -1603,13 +1605,13 @@ gst_jammo_sampler_set_property (GObject * object, guint prop_id,
 	}
 
 	else { //adding non-realtime (nothing special)
-			printf("non-realtime\n");
+			//printf("non-realtime\n");
 			}
 
 	src->eventlist = g_list_insert_sorted(src->eventlist ,event,compare_event_time);
 
 
-	printf("DEBUG: gstjammosampler: added event %llu ms: note:'%u'(%s %d) ,type=%s\n",(unsigned long long)(event->timestamp/1000/1000),note,jammomidi_note_to_char(note),note/12,event->type==JAMMOMIDI_NOTE_ON? "start":"stop");
+	//printf("DEBUG: gstjammosampler: added event %llu ms: note:'%u'(%s %d) ,type=%s\n",(unsigned long long)(event->timestamp/1000/1000),note,jammomidi_note_to_char(note),note/12,event->type==JAMMOMIDI_NOTE_ON? "start":"stop");
 
 	break;
     case PROP_CLEAR_EVENTS:
