@@ -153,6 +153,51 @@ gboolean process_data(gems_connection* c,serverdata* data)
 				}
 				g_free(username);
 			}
+			
+			else if(gems_connection_get_16(c,sizeof(gint16)+sizeof(gint32)) == PROFILE_FULL)
+			{
+				gint position = sizeof(gint16)+sizeof(gint32)+sizeof(gint16);
+			
+				gchar* username = gems_connection_get_char(c,position); // do not free, points to username in buffer!!
+				position = position + strlen(username) + 1;
+			
+				guint32 userid = gems_connection_get_32(c,position);
+				position = position + sizeof(guint32);
+			
+				guint16 age = gems_connection_get_16(c,position);
+				position = position + sizeof(guint16);
+			
+				guint32 aid = gems_connection_get_32(c,position);
+				position = position + sizeof(guint32);
+			
+				gchar* firstname = gems_connection_get_char(c,position); // do not free, points to username in buffer!!
+				position = position + strlen(firstname) + 1;
+			
+				gchar* lastname = gems_connection_get_char(c,position); // do not free, points to username in buffer!!
+				position = position + strlen(lastname) + 1;
+			
+				guint32 points = gems_connection_get_32(c,position);
+			
+				gchar* logmsg = g_strdup_printf("Got full profile: userid:%u username: %s age:%d fullname:%s %s points:%u avatar:%u", 
+					userid,username,age,firstname,lastname,points,aid);
+				cem_add_to_log(logmsg,J_LOG_INFO);
+				g_free(logmsg);
+				
+				jammo_profile_container* prof = gems_teacher_server_get_profile_for_user_id(data->database,userid);
+				
+				// found, update
+				if(prof)
+				{
+					if(g_strcmp0(prof->username,username) == 0)
+					{
+						prof->points = points;
+						prof->avatarid = aid;
+						cem_add_to_log("Points and avatar updated.",J_LOG_INFO);
+					}
+					else cem_add_to_log("Username changed, not updated",J_LOG_ERROR);
+				}
+				else cem_add_to_log("Not a valid profile, ignoring",J_LOG_INFO);
+			}
 			break;
 		case ERROR_MSG:
 			// TODO handle error messages
@@ -426,21 +471,21 @@ void create_profile_to_database(teacher_server_profile_data* data)
 	while(gems_teacher_server_get_profile_for_user_id(data,id)) id = g_rand_int(grand);
 	
 	// here be bug, TODO fix it
-	gchar* agestring = (gchar*)g_malloc0(sizeof(gchar*)*3);
+	gchar* agestring = (gchar*)g_malloc0(sizeof(gchar*)*4);
 	guint16 age = 0;
 	while(do_more)
 	{
 		printf("Age (2 char max!): ");
-		if(fgets(agestring,3,stdin))
+		if(fgets(agestring,4,stdin))
 		{
 			gems_erase_newline(agestring);
 			// Check for integers
 			if(gems_all_integers(agestring))
 			{
 				age = (guint16)atoi(agestring);
-				do_more = FALSE;
+				if(age < 100)	do_more = FALSE;
 			}
-			else memset(agestring,0,3);
+			else memset(agestring,0,4);
 		}
 	}
 	do_more = TRUE;
@@ -454,7 +499,7 @@ void create_profile_to_database(teacher_server_profile_data* data)
 	while(do_more)
 	{
 		printf("Avatar id (%u char max!): ",maxlen);
-		if(fgets(avataridstring,maxlen,stdin))
+		if(fgets(avataridstring,maxlen+1,stdin))
 		{
 			gems_erase_newline(avataridstring);
 			// Check for integers
@@ -495,6 +540,8 @@ int main(int argc,char* argv[])
 {
 	gint pport = 0,tport = 0;
 	serverdata* data = new_data_container();
+	gchar stdinput[100];
+	memset(&stdinput,0,100);
 	
 	cem_set_log_level(J_LOG_DEBUG+J_LOG_INFO+J_LOG_ERROR+J_LOG_NETWORK_DEBUG);
 	signal(SIGTERM,sighandler);
@@ -514,7 +561,11 @@ int main(int argc,char* argv[])
 	data->database = load_database(data->database);
 	if(!data->database) exit(1);
 	gems_teacher_server_print_profile_list(data->database->profiles);
-	cem_add_to_log("Teacher profile service, press Ctrl+C to terminate, press Enter to start entering new profile to database", J_LOG_INFO);
+	cem_add_to_log("------------------------------------------------------------",J_LOG_INFO);
+	cem_add_to_log("Teacher profile service, press Ctrl+C to terminate.",J_LOG_INFO);
+	cem_add_to_log("Type \"add\" to enter new profile to database.", J_LOG_INFO);
+	cem_add_to_log("Type \"set\" to set a username to login for specific device.", J_LOG_INFO);
+	cem_add_to_log("------------------------------------------------------------",J_LOG_INFO);
 	
 	if(ph_c_init(data->ph,argc,argv) == TRUE)
 	{
@@ -556,11 +607,93 @@ int main(int argc,char* argv[])
 							if(FD_ISSET(0,&s)) // stdin
 							{
 								// Enter pressed, entering a new profile data
-								if(getc(stdin) == '\n') create_profile_to_database(data->database);
+								if(fgets(stdinput,100,stdin) == NULL) break;
+								
+								gems_erase_newline(stdinput);
+								
+								if(g_strcmp0(stdinput,"add") == 0) create_profile_to_database(data->database);
+								
+								if(g_strcmp0(stdinput,"set") == 0)
+								{
+									if(g_list_length(data->clients) <= 0)
+									{
+										cem_add_to_log("no clients",J_LOG_INFO);
+										break;
+									}
+									
+									guint32 pnmbr = 0;
+									gchar tmpstr[12];
+									memset(&tmpstr,0,12);
+									
+									cem_add_to_log("Select a profile (give user id number)",J_LOG_INFO);
+									
+									gems_teacher_server_print_profile_list(data->database->profiles);
+									
+									// Get avatar id
+									if(fgets(tmpstr,12,stdin) == NULL) break;
+									else
+									{
+										gems_erase_newline(tmpstr);
+										if(gems_all_integers(tmpstr)) pnmbr = (guint32)strtoul(tmpstr,NULL,10);
+										else break;
+									}
+									
+									// Get profile for id
+									jammo_profile_container* cont = gems_teacher_server_get_profile_for_user_id(data->database,pnmbr);
+									if(!cont) break;
+									
+									cem_add_to_log("Selected profile:",J_LOG_INFO);
+									gems_teacher_server_print_profile(cont);
+									
+									gint cnmbr = 0;
+									
+									// Select connection
+									cem_add_to_log("Select a connection (give order number)",J_LOG_INFO);
+									for(gint i = 0; i < g_list_length(data->clients); i++)
+									{
+										gchar* log = g_strdup_printf("%d: %u",i,
+											ph_c_connection_get_device_checksum(((gems_connection*)(g_list_nth(data->clients,i)->data))->connection));
+										cem_add_to_log(log,J_LOG_INFO);
+										g_free(log);
+									}
+									
+									// Get connection number
+									if(fgets(tmpstr,12,stdin) == NULL) break;
+									else
+									{
+										gems_erase_newline(tmpstr);
+										if(gems_all_integers(tmpstr)) cnmbr = (guint32)strtoul(tmpstr,NULL,10);
+										else break;
+									}
+									
+									// Create message
+									gems_message* msg = gems_create_message_control_set_login_name(cont->username);
+									// Get connection
+									gems_connection* cn = (gems_connection*)(g_list_nth(data->clients,cnmbr)->data);
+									
+									if(gems_communication_write_encrypted_data(JAMMO_PACKET_ADMIN,cn,msg))
+										cem_add_to_log("Sent set username to first user in list",J_LOG_INFO);
+									else cem_add_to_log("Cannot send set username",J_LOG_INFO);
+								
+									gems_clear_message(msg);
+								}
+								
+								if(g_strcmp0(stdinput,"get") == 0)
+								{
+									gems_message* msg = gems_create_message_profile_request(GET_PROFILE_FULL);
+									
+									GList* iter = NULL;
+									
+									for(iter = g_list_first(data->clients); iter; iter = g_list_next(iter))
+									{
+										gems_communication_write_encrypted_data(JAMMO_PACKET_ADMIN,(gems_connection*)iter->data,msg);
+									}
+								}
 							}
 							break;
 					}
 					FD_CLR(0,&s);
+					memset(&stdinput,0,100);
 				
 					g_usleep(500000);
 				}
